function options = Baseline_Definition(modes,NW,Input,ImpData)
%BASELINE_DEFINITION Set options structure to baseline values
% Also soak up Input-struct values neeeded in the simulation runs and save
% them to options-struct (to prevent the need to carry Input-struct around
% beyond this stage).


%% activate results plots
% 1 = active, 0 = inactive
options.plots_active = 0;

%% EA
% = 1 to activate module in EA_DecisionMaking
options.EA.ChangeStock = 1; % Allow hhs to change stock (+-1 per period)
options.EA.RandomBuy = 1; % EEA decision might be overruled by random choice
options.EA.TechnicalPS = 1; % Account for technical delay due to late intro of labels
options.EA.YearsIntroLabel = Input.EA.YearsIntroLabel;
options.EA.large.REPoorChng = Input.EA.large.RenewEveryPoorChng;
options.EA.Price_EEA = 0;
options.EA.PriceEEA = Input.EA.PriceEEA;
options.EA.ShifterEEAPS_Cost = Input.EA.ShifterEEAPS_Cost;
options.EA.PriceElasticityEA = Input.EA.PriceElasticityEA;
options.EA.PricePremiumEEA = Input.EA.PricePremiumEEA;
options.EA.lifetimeEA = Input.EA.lifetimeEA;
options.EA.Cost = 1;
options.EA.CostSizeAlternative = 2;
options.EA.budget_constraint = 1;
options.EA.PS_Conversations = 1;

% probability of HHs to be budget constraint if not rich
% 50% of poor HHs
% based on own assumption/ BFS: Erhebung ber die Einkommen und Lebensbedingungen (SILC))
options.EA.probability_budget_contraint = 0.5;

% define EA price change by iteration
if Input.EA.price_sceanrio_ea == 0% constant price development 
    options.EA.TrendPriceEEA(1:10) = 0;
    options.EA.TrendPriceNonEEA(1:10) = 0;
    
elseif Input.EA.price_sceanrio_ea == 1% historic price development  
    options.EA.TrendPriceEEA(1:10) = Input.EA.TrendPriceEEA(1:10);
    options.EA.TrendPriceNonEEA(1:10) = Input.EA.TrendPriceNonEEA(1:10);

elseif Input.EA.price_sceanrio_ea == 2 % future price development 
    options.EA.TrendPriceEEA(1:10) = Input.EA.FutureTrendPriceEEA(1:10);
    options.EA.TrendPriceNonEEA(1:10) = Input.EA.FutureTrendPriceNonEEA(1:10);
    
elseif Input.EA.price_sceanrio_ea == 3 % subsidy EEA
    options.EA.TrendPriceEEA(1) = 0;
    options.EA.TrendPriceEEA(2) =  -196; % 13% compared to previous price or 3% cheaper as NonEEA
    options.EA.TrendPriceEEA(3) = 0;
    options.EA.TrendPriceEEA(4) = 0;
    options.EA.TrendPriceEEA(5) = 0;
    options.EA.TrendPriceEEA(6) = 0;
    options.EA.TrendPriceEEA(7) = 0;
    options.EA.TrendPriceEEA(8) = 0;
    options.EA.TrendPriceEEA(9) = 0;
    options.EA.TrendPriceEEA(10) = 0;
    
    options.EA.TrendPriceNonEEA(1:10) = 0;   
    
elseif Input.EA.price_sceanrio_ea == 4 % higher subsidy EEA
    options.EA.TrendPriceEEA(1) = 0;
    options.EA.TrendPriceEEA(2) =  -450; % 30% compared to previous price
    options.EA.TrendPriceEEA(3) = 0;
    options.EA.TrendPriceEEA(4) = 0;
    options.EA.TrendPriceEEA(5) = 0;
    options.EA.TrendPriceEEA(6) = 0;
    options.EA.TrendPriceEEA(7) = 0;
    options.EA.TrendPriceEEA(8) = 0;
    options.EA.TrendPriceEEA(9) = 0;
    options.EA.TrendPriceEEA(10) = 0;    
    
    options.EA.TrendPriceNonEEA(1:10) = 0;    

end


%% EU
options.EU.Desc = 1; % active descriptive norm channel (corr=caus)
options.EU.EEAEnergyReduction = Input.EU.EEAEnergyReduction;
options.EU.Price = 1;
options.EU.min_effort = Input.EU.min_effort;
options.EU.max_savings_by_effort = Input.EU.max_savings_by_effort;
options.EU.max_effortlevel = Input.EU.max_effortlevel;
options.EU.PriceEU = Input.EU.PriceEU;
options.EU.PriceElasticity = Input.EU.PriceElasticity;
options.EU.ReboundEffect = 1;
% Design rebound: 1 = in i2 compare to inital effort; 2 = in i2 compare to
% intial effort with rebound
options.EU.ReboundEffectDesign = 2;
options.EU.ReboundEffectMax = Input.EU.ReboundEffectMax;
options.EU.ReboundEffectMin = Input.EU.ReboundEffectMin;
options.EU.Effort_Conversations = 1;

% define if historic trend in EU considered (=1) or not (=0)
options.EU.TrendEU = Input.EU.TrendEU;
options.EU.TrendEU_ChangeYear = Input.EU.TrendEU_ChangeYear; % size of change by trend (%)

% define EU price change by iteration
if Input.EU.price_sceanrio_eu == 0  % constant prices
    options.EU.TrendPriceEU(1:10) = 0;
    
elseif Input.EU.price_sceanrio_eu == 1  % historic price development 
    options.EU.TrendPriceEU(1:10) = Input.EU.TrendPriceEU(1:10);

elseif Input.EU.price_sceanrio_eu == 2% future price development 
    options.EU.TrendPriceEU(1:10) = Input.EU.FutureTrendPriceEU(1:10);
   
end

%% ID
switch modes.ID
    case 'active'
        % Determine here what kind of ID take place and specify them.
        
        %%%%%%%%%%%%%%
        % Information diffusion through conversations:
        % PickMates: 'random' 'byCl', and/or by NW (enter NW name)
        PickMates = char('Family','Friends','Neighborhood','random');

        NumMates.mean = [7.5 2.5 2.5 2.5]; % avg number of encounters /ip
        NumMates.se = [5 7.5 2.5 5]; % normal distribution
            
        % Ties: optional arg if PickMates by NW: 'equal' or 'strongweak' 
        %Ties = char('equal','equal','',''); 
        Ties = char('strongweak','strongweak','strongweak','');         
        % TopicScore: optional arg
        % Set by ID_options to default values, if not specified here.
        % TSs determine probability for each topic of conversation. 
        % This score value can be increased by certain conditions (e.g.
        % EEA_share close to 1).
        options.ID.PickMates = PickMates;
        
        % Conversation EU: 
        % use EU or effort to define direction (=0) or use injunctive norm
        % pressure (=1)
         options.ID.Conv_Direction_eu_effort = 1;
        
        % define if eu level or effort used to define direction in
        % adjusting effort in conversations: 'eulevel' or 'effort'       
        options.ID.Conv_ReferenceDirectionEffortChange = char('eulevel');
     
        
        % Use Lit level to define direction for learning (=1)
        options.ID.Conv_Direction_Lit = 1; 
   
        
        % if 1, use inj norms to define direction
        options.ID.Conv_Direction_ea = 1;    
 
        
        % Define weights for adjustment of preferred EEA share and for EU
        % consumption through conversations      
        
        options.ID.WeightEEA(1,1) = 0.0167;
        options.ID.WeightEEA(1,2) = 0.0333;
        options.ID.ShifterEEA(1,1) = 0.0333;
        options.ID.ShifterEEA(1,2) = 0.0667;

        options.ID.WeightEU(1,1) = 0.0167;
        options.ID.WeightEU(1,2) = 0.0333;
        options.ID.ShifterEU(1,1) = 0.0333;
        options.ID.ShifterEU(1,2) = 0.0667;

        options.ID.WeightInfo(1,1) = 0.0167;
        options.ID.WeightInfo(1,2) = 0.0333;
        options.ID.ShifterInfo(1,1) = 0.0333;
        options.ID.ShifterInfo(1,2) = 0.0667;
        
        % Effect of being limited by Info if IT is active: 
        % new change = old change * (1-LBI)
        options.ID.LBIEU = 0.25; % EU
        options.ID.LBIEEA = 0.25; % EEA

        % EA-specific paramters:
        % Share of EEA to define EEA_Influencer (set to 1 to switch off)
        options.ID.EEA_InfDefShare = 1; 
        % TopicScore multiplier if conversation with influencer 
        % (=0 not more likely, =1 double the TS, ...)
        options.ID.TSEAInflMult = 2; 
        
        % TopicScore multiplier if campaign
        % (=0 not more likely, =1 double the TS, ...)
        options.ID.TSEACampaignMult= 3;  
        %options.ID.TSEACampaignMult= 9;  
        
        % set ID campaign (desc, inj, lit)
        if Input.ID.Campaign == 0
            options.ID.Campaign = '';
        elseif Input.ID.Campaign == 1
            options.ID.Campaign = 'desc';
        elseif Input.ID.Campaign == 2
            options.ID.Campaign = 'inj';
        elseif Input.ID.Campaign == 3
            options.ID.Campaign = 'lit';
        end
        
        % EU-specific parameters
        % Extra weight for large EAs to when computing comparable EU levels
        options.ID.EULSExtraWeight = 1; % 0: no extra weight, 1: double...
        % Critical relative difference in (comparable) EU levels to define 
        % direction of influence: EU1/2<=(1-EUCritLev)EU2/1
        options.ID.EUCritDiff = 0.2;

        for id = 1:numel(PickMates(:,1))
            PM = strrep(PickMates(id,:),' ','');
            T = strrep(Ties(id,:),' ','');
            NM.mean = NumMates.mean(id);
            NM.se = NumMates.se(id);
            options = ID_options(options,NW,PM,NM,T);
        end
        
        
        %%%%%%%%%%%%%%
        % Information diffusion through institutions
           
        if Input.ID.SNCampaign ==1         
                %%%% 1st definition of institutional ID channel: SFOE activates
                %   descriptive norm channel to affect PreferredShareEEA.
                Name{1} = 'SFOE_PSEEA_Desc';
                ChangeVar{1} = char('EA','large','EEA','PreferredShare'); 
                AxisLabel{1} = 'Preferred Share of EEA';
                RefD{1} = 1; % define if NW variable used as reference or not
                % Reference: use EEAshare of bought EAs in the "first" neighborhood
                % NW (ignore secondary NW associations)        
                ReferenceDef{1} = char('Neighborhood','EA','Buy','EEAshare');% not used
                ReferenceVar{1} = char('hh','EA','large','EEA','avgPSTop20');% this one is used
                ITverb{1} = 'Trust'; % Info or Trust
                ITnoun{1} = 'SFOE'; % SFOE or utility
                Channel{1} = 'Desc'; % Desc or Inj
                Relation{1} = 'geq'; % Defines what is "ok": ChangeVar compared to ...
                % ReferenceVar; can be greater/equal (geq), equal (eq), less/equal (leq)
                if Input.ID.max_campaing_effect == 0
                    MaxEffect{1} = 0.*[1 .7 .5 0 0];
                else
                    MaxEffect{1} = 1.*[1 .7 .5 0 0];
                end
                
                if Input.ID.SNCampaignPeriod == 0
                    CampaignPeriod{1} = []; % define period of SN campaign 
                elseif Input.ID.SNCampaignPeriod == 1
                    CampaignPeriod{1} = [4]; % define period of SN campaign 
                elseif Input.ID.SNCampaignPeriod ==2
                    CampaignPeriod{1} = [3 4 5]; % define period of SN campaign 
                end
                Ceil{1} = 1; % Upper limit of target variable
                Floor{1} = 0; % Lower limit of target variable 
                
                % define if target specific campaign and for which cluster
                if Input.ID.TargetClusterSN == 0
                    TargetClusterSN{1} = 0;
                elseif Input.ID.TargetClusterSN == 1
                    TargetClusterSN{1} = 1;
                elseif Input.ID.TargetClusterSN == 2
                    TargetClusterSN{1} = 2;
                elseif Input.ID.TargetClusterSN == 3
                    TargetClusterSN{1} = 3;
                elseif Input.ID.TargetClusterSN == 4
                    TargetClusterSN{1} = 4;
                elseif Input.ID.TargetClusterSN == 5
                    TargetClusterSN{1} = 5;
                elseif Input.ID.TargetClusterSN == 6 % campaign for cluster 1 & cluster 2
                    TargetClusterSN{1} = 6; 
                elseif Input.ID.TargetClusterSN == 7 % campaign for cluster 3 & cluster 4
                    TargetClusterSN{1} = 7;
                end 
                
        elseif Input.ID.SNCampaign ==2          
                %%%% 1st definition of institutional ID channel: SFOE activates
                %   injunctive norm channel to affect PreferredShareEEA.
                Name{1} = 'SFOE_PSEEA_Inj';
                ChangeVar{1} = char('EA','large','EEA','PreferredShare'); 
                AxisLabel{1} = 'Preferred Share of EEA';
                RefD{1} = 1; % define if NW variable used as reference or not
                % Reference: use EEAshare of bought EAs in the "first" neighborhood
                % NW (ignore secondary NW associations)        
                ReferenceDef{1} = char('Neighborhood','EA','Buy','EEAshare');% not used
                ReferenceVar{1} = char('hh','EA','large','EEA','avgPSTop20');% this one is used
                ITverb{1} = 'Trust'; % Info or Trust
                ITnoun{1} = 'SFOE'; % SFOE or utility
                Channel{1} = 'Inj'; % Desc or Inj
                Relation{1} = 'geq'; % Defines what is "ok": ChangeVar compared to ...
                % ReferenceVar; can be greater/equal (geq), equal (eq), less/equal (leq)
                if Input.ID.max_campaing_effect == 0
                    MaxEffect{1} = 0.*[1 .7 .5 0 0];
                else
                    MaxEffect{1} = 1.*[1 .7 .5 0 0];
                end
                
                if Input.ID.SNCampaignPeriod == 0
                    CampaignPeriod{1} = []; % define period of SN campaign 
                elseif Input.ID.SNCampaignPeriod == 1
                    CampaignPeriod{1} = [4]; % define period of SN campaign 
                elseif Input.ID.SNCampaignPeriod ==2
                    CampaignPeriod{1} = [3 4 5]; % define period of SN campaign 
                end
                Ceil{1} = 1; % Upper limit of target variable
                Floor{1} = 0; % Lower limit of target variable
                
                % define if target specific campaign and for which cluster
                if Input.ID.TargetClusterSN == 0
                    TargetClusterSN{1} = 0;
                elseif Input.ID.TargetClusterSN == 1
                    TargetClusterSN{1} = 1;
                elseif Input.ID.TargetClusterSN == 2
                    TargetClusterSN{1} = 2;
                elseif Input.ID.TargetClusterSN == 3
                    TargetClusterSN{1} = 3;
                elseif Input.ID.TargetClusterSN == 4
                    TargetClusterSN{1} = 4;
                elseif Input.ID.TargetClusterSN == 5
                    TargetClusterSN{1} = 5;
                elseif Input.ID.TargetClusterSN == 6 % campaign for cluster 1 & cluster 2
                    TargetClusterSN{1} = 6;
                elseif Input.ID.TargetClusterSN == 7 % campaign for cluster 3 & cluster 4
                    TargetClusterSN{1} = 7;
                end 
        end
    

        if ~isfield(options.ID,'Inst')
            options.ID.Inst.Channels = char(Name); % save names of ID campaigns
            for j = 1:numel(Name)
                options.ID.Inst.(Name{j}).ChangeVar = ChangeVar{j};
                options.ID.Inst.(Name{j}).AxisLabel = AxisLabel{j};
                options.ID.Inst.(Name{j}).ReferenceDef = ReferenceDef{j};
                options.ID.Inst.(Name{j}).ITverb = ITverb{j};
                options.ID.Inst.(Name{j}).ITnoun = ITnoun{j};
                options.ID.Inst.(Name{j}).Channel = Channel{j};
                options.ID.Inst.(Name{j}).Relation = Relation{j};
                options.ID.Inst.(Name{j}).MaxEffect = MaxEffect{j};
                options.ID.Inst.(Name{j}).CampaignPeriod = CampaignPeriod{j};
                options.ID.Inst.(Name{j}).Ceil = Ceil{j};
                options.ID.Inst.(Name{j}).Floor = Floor{j};
                options.ID.Inst.(Name{j}).RefD = RefD{j};
                options.ID.Inst.(Name{j}).ReferenceVar = ReferenceVar{j};
                options.ID.Inst.(Name{j}).TargetClusterSN = TargetClusterSN{j};
                
            end
        end

        % Options for Literacy campaign
        options.ID.ClusterTailoredLitCampaign = 0; % define is cluster specific campaign and for which cluster (0 = no, 1 = cl1, ...)
        options.ID.Literacy = 0; % set to 1 to activate literacy channel 
        options.ID.MaxEffectLitCampaign = [2 1 0.5 0 0]; % define effect on current literacy level
        if Input.ID.LitCampaignPeriod == 0
            options.ID.LitCampaignPeriod = []; % define period of Lit campaign 
        elseif Input.ID.LitCampaignPeriod == 1
            options.ID.LitCampaignPeriod = [4]; % define period of Lit campaign 
        elseif Input.ID.LitCampaignPeriod ==2
            options.ID.LitCampaignPeriod = [3 4 5]; % define period of Lit campaign 
        end
        options.ID.campaignsender_lit = 'SFOE'; % define sender    
        options.ID.ReferenceLitLevel = ''; % reference literacy level:
        % can be "no_ref" if percentage change of current lit level used
        % or lit level from one of the networks (define which network: 'Family','Neighborhood','Friends')
        options.ID.RelationLitChange = 'geq'; % Defines what is "ok": ChangeVar compared to ...
        % ReferenceVar; can be greater/equal (geq), equal (eq), less/equal (leq)
        options.ID.LowerLimitLitChange = -3; % Lower limit of target variable
        options.ID.UpperLimitLitChange = 3; % Upper limit of target variable
        
        if Input.ID.TargetLiteracyCampaign == 0
            options.ID.LiteracyTarget= 'PE'; % define target of campaign: 'PE','PS' or 'PS_PE'
        elseif Input.ID.TargetLiteracyCampaign == 1
            options.ID.LiteracyTarget= 'PS'; % define target of campaign: 'PE','PS' or 'PS_PE'
        elseif Input.ID.TargetLiteracyCampaign == 2
            options.ID.LiteracyTarget= 'PS_PE'; % define target of campaign: 'PE','PS' or 'PS_PE'  
        end
        
        % set option for learning: does learning change PS and
        % effort? 1 = yes, 0 = no
        options.ID.Learning = 1;

end

%% Network effect of desc norm on EU (treat corr as causal effect)
options.NW = Input.NW; % store NW specs in options (needed in Simulation.m)
options.NW.NWon = strncmp('active',modes.NW,6);
% For decision on new EEA in NWon=1 mode
options.NW.WeightPSMax = 0.5; % weight of PreferredShareMax, relative to avg PreferredShare
% Setting slope and the relative weight of descriptive information effect 
% on electricity use 
options.NW.EUDesc.slope = zeros(5,1);
options.NW.EUDesc.weight = zeros(5,1);
for desc = 2:5
    options.NW.EUDesc.slope(desc) = exp(ImpData.Elec_Use_marg_cl5.predict(desc))...
        - exp(ImpData.Elec_Use_marg_cl5.predict(desc-1));
end
for desc = 2:5
    options.NW.EUDesc.weight(desc) = sum(options.NW.EUDesc.slope(1:desc))...
        /sum(options.NW.EUDesc.slope);
end


end