function hh = BehavioristicAdjustment(hh,NW,modes,options,ip)
% PreferredShare and Effort Adjustment: updates preferred share and effort
%%%%%%%%%
% Input: hh,NW,modes,options,ip structure
%%%%%%%%%
% Returns/updates: updated preferred share and effort


%% prices EA and EU
% price EA from previous iteration
price_eea = hh.EA.priceEEA;
price_noneea = hh.EA.priceNonEEA;
% new price EA after taking into acount trend
price_eea_new = price_eea + options.EA.TrendPriceEEA(ip);
price_noneea_new = price_noneea + options.EA.TrendPriceNonEEA(ip);

% price EU from previous iteration
price_eu = hh.EU.priceEU;
% new price EU after taking into acount trend
price_eu_new = price_eu + options.EU.TrendPriceEU(ip); 



%% change indicator for cost effect:
% only take into account cost effect for those who are likely to replace EA
% or change stock
for cl=1:hh.ClNumber
    hh.EA.ChangeIndicator{cl,1}  = zeros(hh.N(cl),1);
    
    for h=1:hh.N(cl)      
        
        %---- likelihood for replacement
        switch hh.owner{cl,1}(h)
            case 1 % owner
                for s=1:hh.EA.large.stock{cl,1}(h)
                    if rand < 1/(...
                            hh.EA.large.RenewEvery{cl,1}(h)...
                            + (1 - hh.rich{cl,1}(h))...
                                *options.EA.large.REPoorChng...
                            )
                        
                        hh.EA.ChangeIndicator{cl,1}(h) = 1;
                    end
                end
                
            case 0 % Renter
                CurrentBulkSize=round(...
                    hh.EA.large.RenterBulkShare{cl,1}(h)...
                    *hh.EA.large.stock{cl,1}(h)...
                    );
                % 1. for bulk part
                for s=1:CurrentBulkSize
                    if rand < 1/(...
                            hh.EA.large.RenewEvery{cl,1}(h)...
                            + ( 1 - hh.rich{cl,1}(h))...
                                *options.EA.large.REPoorChng...
                            )...
                            /CurrentBulkSize 
                        
                        hh.EA.ChangeIndicator{cl,1}(h) = 1;
                    end
                end
                % 2. for non-bulk-part
                for s=CurrentBulkSize+1:hh.EA.large.stock{cl,1}(h)
                    if rand < 1/(...
                            hh.EA.large.RenewEvery{cl,1}(h)...
                            + (1 - hh.rich{cl,1}(h))...
                                *options.EA.large.REPoorChng...
                            )
                        
                        hh.EA.ChangeIndicator{cl,1}(h) = 1;
                    end
                end
        end
        
        %---- likelihood change stock
        switch hh.large{cl,1}(h)
            case 1 % decide to change stock more frequently if large hh
                NewProb = (1+ hh.EA.ChangeStock.LargeFreq{cl,1}(h))...
                       * hh.EA.ChangeStock.prob{cl,1}(h);           
            case 0 % small hh
                NewProb = hh.EA.ChangeStock.prob{cl,1}(h);
        end  
        switch hh.rich{cl,1}(h)
            case 1 % increase less likely if poor
                NewIncr = hh.EA.ChangeStock.increase{cl,1}(h);
            case 0
                NewIncr = (1-hh.EA.ChangeStock.PoorDecrMarkup{cl,1}(h)) ...
                    * hh.EA.ChangeStock.increase{cl,1}(h);
        end
    
        if hh.EA.ChangeIndicator{cl,1}(h) == 0
            if rand < NewProb
                if rand < NewIncr
                    
                	hh.EA.ChangeIndicator{cl,1}(h) = 1;
                end
            end
        end

%         hh.EA.ChangeIndicator{cl,1}(h) = 1;
    end    
end


                                                              
%% Change in preferred share
for cl=1:hh.ClNumber
        hh.EA.ChangeStock.CS{cl,1}(:) = 0;
        change_PS_Lit = zeros(hh.N(cl),1);
        change_PS_Lit_learning = zeros(hh.N(cl),1);
        PreferredShare_Old = hh.EA.large.EEA.PreferredShare{cl,1};
        hh.EA.large.EEA.TechnicalPS{cl,1} = zeros(hh.N(cl),1);
        hh.EA.large.EEA.ChangePSTechnical{cl,1} = zeros(hh.N(cl),1);
        hh.EA.large.EEA.ChangePSCost{cl,1} = zeros(hh.N(cl),1);
        hh.EA.CostWeight{cl,1} = zeros(hh.N(cl),1);
        hh.EA.ValuedCostEEA{cl,1} = zeros(hh.N(cl),1);
        hh.EA.ValuedCostNonEEA{cl,1} = zeros(hh.N(cl),1);
        hh.EA.RelativeValuedCostsEEA{cl,1} = zeros(hh.N(cl),1);
        hh.EA.ChangeEEAPS_Cost{cl,1} = zeros(hh.N(cl),1);
        hh.EA.large.EEA.Change_PS_Conv{cl,1} = zeros(hh.N(cl),1);
        
    %--------------- Cost effect: relative costs EEA ---------------------        
    switch options.EA.Cost
        case 1
            AcquisitionCostsEEA = price_eea_new; 
            % operating costs: CHF/KWh * BaseKWh * lifetime
            % not discounted as no perfect investment decision assumed
            OperatingCostsEEA = price_eu_new...
                                * hh.EU.mean_Base_EEA...
                                * options.EA.lifetimeEA; 
                            
            AcquisitionCostsNonEEA = price_noneea_new;  
            OperatingCostsNonEEA = price_eu_new...
                                * hh.EU.mean_Base_NONEEA...
                                * options.EA.lifetimeEA; 

            % define range in which HH values AcquisitionCosts:
            % rich might value AcquisitionCosts also higher, but not as
            % much as poor
            costweight_rich_min = 1; 
            costweight_rich_max = 1.25;
            costweight_poor_min = 1.25; 
            costweight_poor_max = 2;
            


            for h=1:hh.N(cl)
                if hh.rich{cl,1}(h)==1
                        % define cost weight for AcquisitionCosts with some
                        % random effects in min max range
                        hh.EA.CostWeight{cl,1}(h) = (costweight_rich_max...
                                                    - costweight_rich_min)...
                                                    .*rand + costweight_rich_min;
                else
                    switch options.EA.budget_constraint
                        case 1 % budget constraint active      
                                 % define budget_constrained randomly for poor HH:
                                   %hh.EA.large.budget_constrained{cl,1}(h) = randi([0,1]);
                                   hh.EA.large.budget_constrained{cl,1}(h) = rand < options.EA.probability_budget_contraint;
                                   if hh.EA.large.budget_constrained{cl,1}(h) == 1
                                        hh.EA.CostWeight{cl,1}(h) = 2;
                                   else
                                        hh.EA.CostWeight{cl,1}(h) = (costweight_poor_max...
                                                                                - costweight_poor_min)...
                                                                                .*rand + costweight_poor_min;
                                   end
                        case 0 % budget constraint inactive 
                                hh.EA.CostWeight{cl,1}(h) = (costweight_poor_max...
                                                                                - costweight_poor_min)...
                                                                                .*rand + costweight_poor_min;
                    end
                end
                % calculate valued costs based on weights from above
                hh.EA.ValuedCostEEA{cl,1}(h) = hh.EA.CostWeight{cl,1}(h)...
                                                .* AcquisitionCostsEEA...
                                                + (2-hh.EA.CostWeight{cl,1}(h))...
                                                .* OperatingCostsEEA;
                hh.EA.ValuedCostNonEEA{cl,1}(h) = hh.EA.CostWeight{cl,1}(h)... 
                                                    .* AcquisitionCostsNonEEA...
                                                    + (2-hh.EA.CostWeight{cl,1}(h))...
                                                    .* OperatingCostsNonEEA;
                % valued costs for EEA relative to NonEEA
                hh.EA.RelativeValuedCostsEEA{cl,1}(h) = hh.EA.ValuedCostEEA{cl,1}(h)...
                                                        / hh.EA.ValuedCostNonEEA{cl,1}(h);
                                                    
                if hh.EA.ChangeIndicator{cl,1}(h) == 1 % only change by cost if change indicator = 1
                    % define percentage change in EEA_PS based on
                    % relative costs EEA:
                    % Case 1: define size of effect exogenously (in EA_Paramters)
                    % Case 2: use PriceElasticityEA to define size of effect
                    switch options.EA.CostSizeAlternative
                        case 1 % define size of effect exogenously (in EA_Paramters)
                            if hh.EA.RelativeValuedCostsEEA{cl,1}(h) > 1 % EEA more expensive than NonEEA
                                % assumption that rich decrease or increase their EEA_PS by 10% because of relative costs EEA, 
                                % poor decrease or increase their EEA_PS by 25% because of relative costs EEA
                                hh.EA.ChangeEEAPS_Cost{cl,1}(h) = 1 - options.EA.ShifterEEAPS_Cost(hh.rich{cl,1}(h)+1);                       
                            else % EEA cheaper than nonEEA 
                                hh.EA.ChangeEEAPS_Cost{cl,1}(h) = 1 + options.EA.ShifterEEAPS_Cost(hh.rich{cl,1}(h)+1);  
                            end  

                        case 2 % use PriceElasticityEA to define size of effect
                            hh.EA.ChangeEEAPS_Cost{cl,1}(h) = ...
                                ((hh.EA.ValuedCostEEA{cl,1}(h)...
                                    - hh.EA.ValuedCostNonEEA{cl,1}(h))...
                                    ./ hh.EA.ValuedCostNonEEA{cl,1}(h))...
                                    .* hh.EA.large.EEA.PreferredShare{cl,1}(h) ...
                                    .* options.EA.PriceElasticityEA;

                    end
                end
            end
        % calculate absolute change in EEA_PS due to relative costs EEA to
        % NonEEA
        switch options.EA.CostSizeAlternative
            case 1 % multiplicative effect on PreferredShare
                hh.EA.large.EEA.ChangePSCost{cl,1} = (hh.EA.large.EEA.PreferredShare{cl,1}...
                                                    .* hh.EA.ChangeEEAPS_Cost{cl,1})...
                                                    - hh.EA.large.EEA.PreferredShare{cl,1}; 
            case 2 % additive effect on PreferredShare
                hh.EA.large.EEA.ChangePSCost{cl,1} = hh.EA.ChangeEEAPS_Cost{cl,1};                
        end
        % Limit EEA PreferredShare between 0 and 1                                
        hh.EA.large.EEA.ChangePSCost{cl,1} = min((1-hh.EA.large.EEA.PreferredShare{cl,1}),...
                                                  max(-hh.EA.large.EEA.PreferredShare{cl,1},...
                                                        hh.EA.large.EEA.ChangePSCost{cl,1}));
                   
    end

                   
    %----------------- Price elasticity effect: --------------------------
    % change in PS by price elasticity   
    switch options.EA.Price_EEA
        case 1
            % Change in PreferredShare due to elasticity
            ChangePSbyElasticity = zeros(hh.N(cl),1); 

            % define new price level based on trend and calculate change in PS due to
            % price elasticity effects
            for h=1:hh.N(cl) 
                ChangePSbyElasticity(h) = options.EA.PriceElasticityEA ...
                    * ((price_eea_new - price_eea)/price_eea)...
                    * PreferredShare_Old(h); 
            end
            hh.EA.large.EEA.ChangePSbyElasticity{cl,1} = ChangePSbyElasticity;
            % Limit EEA PreferredShare between 0 and 1                                
            hh.EA.large.EEA.ChangePSbyElasticity{cl,1} = min((1-hh.EA.large.EEA.PreferredShare{cl,1}),...
                                                      max(-hh.EA.large.EEA.PreferredShare{cl,1},...
                                                            hh.EA.large.EEA.ChangePSbyElasticity{cl,1}));

        otherwise
           hh.EA.large.EEA.ChangePSbyElasticity{cl,1} = zeros(hh.N(cl),1);
    end

    %----------------- Institutional effect (and learning effect): ------------------------- 
    % lit level from previous iteration    
    hh.NI.LitOld{cl,1} = hh.NI.Lit{cl,1};
    
    % change in PS by change in literacy due to campaign 
    % lit level including change by lit campaign:  
    literacy_level_new_campaign = zeros(hh.N(cl),1);   
    literacy_level_before_campaign = zeros(hh.N(cl),1);   
       
    switch options.ID.Literacy 
        case 1
            literacy_level_new_campaign = min(11,max(0,(hh.NI.LitOld{cl,1} + hh.NI.change_lit{cl,1}))) + 1;
            literacy_level_before_campaign = hh.NI.LitOld{cl,1} + 1;
            PS_Lit_Elasticity = hh.EA.large.EEA.Elasticity_LitPS{cl,1};
            
            switch options.ID.LiteracyTarget 
                case 'PS'
                    for h=1:hh.N(cl) 
                        % change defined as an elasticity
                        change_PS_Lit(h) = PS_Lit_Elasticity...
                                * ((literacy_level_new_campaign(h) - literacy_level_before_campaign(h)));
                    end 

                case 'PS_PE'
                    for h=1:hh.N(cl) 
                        change_PS_Lit(h) = PS_Lit_Elasticity...
                                * ((literacy_level_new_campaign(h) - literacy_level_before_campaign(h)));            
                    end
            end
        otherwise
            hh.NI.change_lit{cl,1} = zeros(hh.N(cl),1);
    end
    
    % change in PS by change in literacy due to learning
        
    % lit level including change by learning 
    literacy_level_new_learning = zeros(hh.N(cl),1);  
    literacy_level_before_learning = zeros(hh.N(cl),1);  

    switch options.ID.Learning 
        case 1
            literacy_level_new_learning = min(11,max(0,(hh.NI.LitOld{cl,1} + hh.NI.Learning{cl,1}))) + 1;
            literacy_level_before_learning = hh.NI.LitOld{cl,1} + 1;
            PS_Lit_Elasticity = hh.EA.large.EEA.Elasticity_LitPS{cl,1};
            
            for h=1:hh.N(cl) 
            change_PS_Lit_learning(h) = PS_Lit_Elasticity...
                    * ((literacy_level_new_learning(h) - literacy_level_before_learning(h)));
            end
        otherwise
            hh.NI.Learning{cl,1} = zeros(hh.N(cl),1);
    end
    
    hh.EA.large.EEA.change_PS_Lit{cl,1} = change_PS_Lit + change_PS_Lit_learning;
    % Limit EEA PreferredShare between 0 and 1                                
    hh.EA.large.EEA.change_PS_Lit{cl,1} = min((1-hh.EA.large.EEA.PreferredShare{cl,1}),...
                                              max(-hh.EA.large.EEA.PreferredShare{cl,1},...
                                                    hh.EA.large.EEA.change_PS_Lit{cl,1}));
    % update Literacy level
    hh.NI.Lit{cl,1} = min(11,max(0,(hh.NI.LitOld{cl,1} + hh.NI.change_lit{cl,1} + hh.NI.Learning{cl,1})));
   
    %----------------------- Technical effect: --------------------------
        % Set HHPreferredShare in first iteration period. If activated, adjust 
        % for late introduction of labels (TechnicalPS==1)
    switch ip
        case 2
            switch options.EA.TechnicalPS
                case 1
                   % (1-normcdf) * max(PreferredShare,MeanNWPreferredShare) + normcdf * PreferredShare  
                    hh.EA.large.EEA.TechnicalPS{cl,1} = min(1,...
                            (1 - normcdf(options.EA.YearsIntroLabel,...
                                    hh.EA.large.RenewEvery{cl,1},...
                                    hh.EA.large.RenewEvery{cl,1}*0.5))...
                                    .* max(hh.EA.large.EEA.PreferredShare{cl,1},...
                                    mean(NW.Neighborhood.EA.large.EEA.PreferredShare))...
                            + normcdf(options.EA.YearsIntroLabel,...
                                    hh.EA.large.RenewEvery{cl,1},...
                                    hh.EA.large.RenewEvery{cl,1}*0.5)...
                                    .* hh.EA.large.EEA.PreferredShare{cl,1}...  
                        );
                    hh.EA.large.EEA.ChangePSTechnical{cl,1} = hh.EA.large.EEA.TechnicalPS{cl,1}...
                                                                - hh.EA.large.EEA.PreferredShare{cl,1};
                    % Limit EEA PreferredShare between 0 and 1                                
                    hh.EA.large.EEA.ChangePSTechnical{cl,1} = min((1-hh.EA.large.EEA.PreferredShare{cl,1}),...
                                                              max(-hh.EA.large.EEA.PreferredShare{cl,1},...
                                                                    hh.EA.large.EEA.ChangePSTechnical{cl,1}));                                                            
            end
        otherwise
    end
    
    %----------------------- Conversations effect: -----------------------
    % effect of conversation on PS active (=1) or
    % inactive (=0)
    switch options.EA.PS_Conversations
        case 1
            hh.EA.large.EEA.Change_PS_Conv{cl,1} = hh.EA.large.EEA.Change_EEA_PS_Conv{cl,1};
            % Limit EEA PreferredShare between 0 and 1                                
            hh.EA.large.EEA.Change_PS_Conv{cl,1} = min((1-hh.EA.large.EEA.PreferredShare{cl,1}),...
                                                      max(-hh.EA.large.EEA.PreferredShare{cl,1},...
                                                            hh.EA.large.EEA.Change_PS_Conv{cl,1})); 
        case 0
            hh.EA.large.EEA.Change_PS_Conv{cl,1} = zeros(hh.N(cl),1);
    end
    
    
    %----------------- all changes in preferred share: --------------------
        % PS = PS 
        %      + change by technical effect 
        %      + change by conversation 
        %      + change by literacy campaign institutions (and learning) 
        %      + change by price elasticity
        %      + change by relative cost EEA to NonEEA
    hh.EA.large.EEA.PreferredShare{cl,1} = hh.EA.large.EEA.PreferredShare{cl,1}...
                                            + hh.EA.large.EEA.ChangePSTechnical{cl,1}...
                                            + hh.EA.large.EEA.Change_PS_Conv{cl,1}...
                                            + hh.EA.large.EEA.change_PS_Lit{cl,1}...
                                            + hh.EA.large.EEA.ChangePSbyElasticity{cl,1}...
                                            + hh.EA.large.EEA.ChangePSCost{cl,1};

    hh.EA.large.EEA.PreferredShare{cl,1} = max(0,min(1,hh.EA.large.EEA.PreferredShare{cl,1}));   
end

% update price EEA and NonEEA
hh.EA.priceEEA = price_eea_new;
hh.EA.priceNonEEA = price_noneea_new;

%% Change in Effort
for cl=1:hh.ClNumber
        change_PE_Lit = zeros(hh.N(cl),1);
        change_PE_Lit_Learning = zeros(hh.N(cl),1);
        EU_effort_old = hh.EU.Effort{cl,1};
        hh.EU.EffortNorm{cl,1} = zeros(hh.N(cl),1); 
        hh.EU.ChangeEffortNorm{cl,1} = zeros(hh.N(cl),1); 
        hh.EU.ChangeEffortLit{cl,1} = zeros(hh.N(cl),1); 
        hh.EU.ChangeEffortReboundEffect{cl,1} = zeros(hh.N(cl),1);
        hh.EU.Change_Effort_Conversations{cl,1} = zeros(hh.N(cl),1);
        hh.EU.LevelDesc{cl,1} = zeros(hh.N(cl),1); 
        

    %------------------- Price elasticity effect: ----------------------- 
    % change in utilisation of EA (effort) by price elasticity:
    switch options.EU.Price
       case 1
            % Change in demand due to elasticity
            ChangeEffortByElasticity = zeros(hh.N(cl),1); 

            % define new price level based on trend and calculate change in EA utilisation due to
            % price elasticity effects
           for h=1:hh.N(cl) 
                ChangeEffortByElasticity(h) = options.EU.PriceElasticity...
                                                * ((price_eu_new...
                                                    - price_eu)...
                                                    / price_eu...
                                                   )...
                                                    * EU_effort_old(h); 
           end
            hh.EU.ChangeEffortByElasticity{cl,1} = ChangeEffortByElasticity;
            % Limit EU_PE between min_EU_PE (=EUFixshare) and 1
            hh.EU.ChangeEffortByElasticity{cl,1} = min((1-hh.EU.Effort{cl,1}),...
                                                max(-(hh.EU.Effort{cl,1}-options.EU.min_effort),...
                                                        hh.EU.ChangeEffortByElasticity{cl,1}));
        otherwise
            hh.EU.ChangeEffortByElasticity{cl,1} = zeros(hh.N(cl),1);
    end

    %---------------- Institutional effect (and learning effect):  -----------------------------

    % change in effort by change in literacy due to campaign

    % lit level including change by lit campaign
    literacy_level_new_campaign = zeros(hh.N(cl),1);   
    literacy_level_before_campaign = zeros(hh.N(cl),1);   
    
    switch options.ID.Literacy 
        case 1
        literacy_level_new_campaign = min(11,max(0,(hh.NI.LitOld{cl,1} + hh.NI.change_lit{cl,1}))) + 1;
        literacy_level_before_campaign = hh.NI.LitOld{cl,1} + 1; 
        PE_Lit_Elasticity = hh.EU.Elasticity_LitEffort;
        
            switch options.ID.LiteracyTarget    
                case 'PE'
                    for h=1:hh.N(cl) 
                        change_PE_Lit(h) = PE_Lit_Elasticity...
                                * ((literacy_level_new_campaign(h) - literacy_level_before_campaign(h)));
                    end

                case 'PS_PE'
                    for h=1:hh.N(cl) 
                        change_PE_Lit(h) = PE_Lit_Elasticity...
                                * ((literacy_level_new_campaign(h) - literacy_level_before_campaign(h)));            
                    end
            end
    end
    
    % change in effort by change in literacy due to learning
        
        % lit level including change by learning 
        literacy_level_new_learning = zeros(hh.N(cl),1);  
        literacy_level_before_learning = zeros(hh.N(cl),1);  
        
        switch options.ID.Learning 
            case 1
                literacy_level_new_learning = min(11,max(0,(hh.NI.LitOld{cl,1} + hh.NI.Learning{cl,1}))) + 1;
                literacy_level_before_learning = hh.NI.LitOld{cl,1} + 1;
                PE_Lit_Elasticity = hh.EU.Elasticity_LitEffort;
                
                for h=1:hh.N(cl) 
                change_PE_Lit_Learning(h) = PE_Lit_Elasticity...
                        * ((literacy_level_new_learning(h) - literacy_level_before_learning(h)));
                end
        end
    
    hh.EU.ChangeEffortLit{cl,1} = change_PE_Lit + change_PE_Lit_Learning;
    % Limit EU_PE between min_EU_PE (=EUFixshare) and 1
    hh.EU.ChangeEffortLit{cl,1} = min((1-hh.EU.Effort{cl,1}),...
                                        max(-(hh.EU.Effort{cl,1}-options.EU.min_effort),...
                                                hh.EU.ChangeEffortLit{cl,1}));
    
    %--------------------- Rebound Effect: ------------------------------
    % change effort by rebound effect: effort reduced if
    % more EEAs 
    % Note: rebound effect lags one iteration as change in EEA stock takes place after Behavioristic Adjustment
    
    switch options.EU.ReboundEffect
        case 1 % 1 if rebound active
            switch ip
                case 2 % in iteration 2
                    switch options.EU.ReboundEffectDesign % two design options
                        case 1 % rebound effect already in initial effort included, thus start with initial effort (leads to strong effort increase in i2)
                            hh.EU.EffortReboundPreviousIter{cl,1} = hh.EU.InitialEffort{cl,1}; 
                        case 2 % rebound effect not in initial effort, thus calculate initial effort with rebound and use as start value
                            hh.EU.EffortReboundPreviousIter{cl,1} = hh.EU.EffortReboundInitial{cl,1};
                    end
                otherwise % in all other iterations
                    hh.EU.EffortReboundPreviousIter{cl,1} = hh.EU.EffortRebound{cl,1};          
            end
                               
            hh.EU.ReboundEffect{cl,1} = zeros(hh.N(cl),1);
            hh.EU.EffortRebound{cl,1} = zeros(hh.N(cl),1);

            for h=1:hh.N(cl)
                % calculate size of rebound effect dependent on share EEA and min
                % max rebound effect:   
                if hh.EA.large.EEA.share{cl,1}(h) > 0  

                    hh.EU.ReboundEffect{cl,1}(h) = (options.EU.ReboundEffectMax - options.EU.ReboundEffectMin)...
                                                    .* hh.EA.large.EEA.share{cl,1}(h)...
                                                    + options.EU.ReboundEffectMin;
                else
                    hh.EU.ReboundEffect{cl,1}(h) = 0;
                end
            end
            % calculate new effort after taking into account rebound effect:
            % Effort Rebound = ((baseEEA after taking into account rebound effect
            %                   * StockEEA * Effort) +  baseNonEEA * StockNonEEA * Effort)
            %                   / (StockEEA * baseEEA + StockNonEEA * baseNonEEA)
            hh.EU.EffortRebound{cl,1} = (hh.EU.mean_Base_NONEEA...
                                            .* (1 - options.EU.EEAEnergyReduction...
                                            .* (1 - hh.EU.ReboundEffect{cl,1}))...
                                            .* hh.EA.large.EEA.stock{cl,1}...
                                            .* hh.EU.InitialEffort{cl,1}...
                                            + hh.EU.mean_Base_NONEEA...
                                            .* (hh.EA.large.stock{cl,1} - hh.EA.large.EEA.stock{cl,1})...
                                            .* hh.EU.InitialEffort{cl,1}...
                                         )...
                                        ./(hh.EU.mean_Base_EEA...
                                            .* hh.EA.large.EEA.stock{cl,1}...
                                            + hh.EU.mean_Base_NONEEA...
                                            .* (hh.EA.large.stock{cl,1} - hh.EA.large.EEA.stock{cl,1})...
                                           ); 
            % set limits for effort with rebound: between min level and 1
            hh.EU.EffortRebound{cl,1} = max(options.EU.min_effort,min(hh.EU.EffortRebound{cl,1},1));
            
            % change in effort by rebound effect 
            hh.EU.ChangeEffortReboundEffect{cl,1} = hh.EU.EffortRebound{cl,1}...
                                                   - hh.EU.EffortReboundPreviousIter{cl,1}; 
            % Limit EU_PE between min_EU_PE (=EUFixshare) and 1
            hh.EU.ChangeEffortReboundEffect{cl,1} = min((1-hh.EU.Effort{cl,1}),...
                                                        max(-(hh.EU.Effort{cl,1}-options.EU.min_effort),...
                                                            hh.EU.ChangeEffortReboundEffect{cl,1}));                                                                                             
    end                               
    
    
        %------------------- Conversations effect: -----------------------
        % effect of conversation on PS active (=1) or
    % inactive (=0)
    switch options.EU.Effort_Conversations
        case 1
            hh.EU.Change_Effort_Conversations{cl,1} = hh.EU.Change_Effort_Conv{cl,1};
            % Limit EU_PE between min_EU_PE (=EUFixshare) and 1
            hh.EU.Change_Effort_Conversations{cl,1} = min((1-hh.EU.Effort{cl,1}),...
                                                        max(-(hh.EU.Effort{cl,1}-options.EU.min_effort),...
                                                            hh.EU.Change_Effort_Conversations{cl,1}));              
        case 0
            hh.EU.Change_Effort_Conversations{cl,1} = zeros(hh.N(cl),1);
    end
    

    % ------------------- all changes in effort: -------------------------
        % Effort = Effort 
        %      + change by norms
        %      + change by price elasticity 
        %      + change by literacy campaign institutions (and learning) 
        %      + change by conversation
        %      + change by rebound effect
   
    hh.EU.Effort{cl,1} = hh.EU.Effort{cl,1}...
                            + hh.EU.ChangeEffortNorm{cl,1}...
                            + hh.EU.ChangeEffortByElasticity{cl,1}...
                            + hh.EU.ChangeEffortLit{cl,1}...
                            + hh.EU.Change_Effort_Conversations{cl,1}...
                            + hh.EU.ChangeEffortReboundEffect{cl,1};
                        
    hh.EU.Effort{cl,1} = max(options.EU.min_effort,min(hh.EU.Effort{cl,1},1));
    
    % Derive effort level:
    % translate utilisation (effort) into effort level (1-5 scale) of EA
    for h=1:hh.N(cl)
           hh.EU.EffortLevel{cl,1}(h,1) = max(1,min(options.EU.max_effortlevel,...
                                                    options.EU.max_effortlevel...
                                                    - ((hh.EU.Effort{cl,1}(h)...
                                                        - options.EU.min_effort)...
                                                            /(options.EU.max_savings_by_effort/4))));
    end
end

% update price EEA
hh.EU.priceEU = price_eu_new;

end