function hh = EA_AssignHH(hh,Input,assign_modes,ip)
%EA_ASSIGNHH Assign electronic appliances: Stocks and Buy measures
%%%%%%%%%
% Input: hh structure, Input, and assign_modes structures, ip
%%%%%%%%%
% Returns: hh structure


%% Set variables to assign
switch ip
    case 1        
        hh.EA.stock{hh.ClNumber,1} = 0;
        hh.EA.MinimumStock = hh.EA.stock;
        hh.EA.ChangeStock.prob = hh.EA.stock;
        hh.EA.ChangeStock.LargeFreq = hh.EA.stock;
        hh.EA.ChangeStock.increase = hh.EA.stock;
        hh.EA.ChangeStock.PoorDecrMarkup = hh.EA.stock;
        hh.EA.ChangeStock.BuyLarge = hh.EA.stock;
        hh.EA.ChangeStock.CS = hh.EA.stock;
        hh.EA.RandomBuy.large.prob = hh.EA.stock;
        hh.EA.large.MinimumStock = hh.EA.stock;
        hh.EA.large.stock = hh.EA.stock;
        hh.EA.large.share = hh.EA.stock;
        hh.EA.large.RenewEvery = hh.EA.stock;
        hh.EA.large.RenterBulkShare = hh.EA.stock;
        hh.EA.large.EEA.PreferredStock = hh.EA.stock; 
        hh.EA.large.EEA.PreferredShare = hh.EA.stock; 
        hh.EA.large.EEA.stock = hh.EA.stock;
        hh.EA.large.EEA.share = hh.EA.stock;               
end

%% Assign EA variables
% Cluster-specific assignment (by category not feasible)

for cl = 1:hh.ClNumber % cluster loop
    hh.EA.MinimumStock{cl,1} = max(0,...
        round(NormalDist(Input.EA.MinimumStock.mean(cl),...
        Input.EA.MinimumStock.sd(cl),hh.N(cl))...
        ));

    hh.EA.large.MinimumStock{cl,1} = max(0,...
        min(hh.EA.MinimumStock{cl,1},...
            round(NormalDist(Input.EA.large.MinimumStock.mean(cl),...
            Input.EA.large.MinimumStock.sd(cl),hh.N(cl))...
            )));
     
    hh.EA.large.RenewEvery{cl,1} = max(0,... 
        NormalDist(Input.EA.large.RenewEvery.mean(cl),...
        Input.EA.large.RenewEvery.sd(cl),hh.N(cl))...
        );
    hh.EA.large.RenterBulkShare{cl,1} = max(0,min(1,round(...
        NormalDist(Input.EA.large.RenterBulkShare.mean(cl),...
        Input.EA.large.RenterBulkShare.sd(cl),hh.N(cl))...
        )));
    
    hh.EA.ChangeStock.prob{cl,1} = min(1,max(0,... 
        NormalDist(Input.EA.ChangeStock.prob.mean(cl),...
        Input.EA.ChangeStock.prob.sd(cl),hh.N(cl))...
        ));
    hh.EA.ChangeStock.LargeFreq{cl,1} = max(0,... 
        NormalDist(Input.EA.ChangeStock.LargeFreqIncrease.mean(cl),...
        Input.EA.ChangeStock.LargeFreqIncrease.sd(cl),hh.N(cl))...
        );
    hh.EA.ChangeStock.increase{cl,1} = min(1,max(0,... 
        NormalDist(Input.EA.ChangeStock.increase.mean(cl),...
        Input.EA.ChangeStock.increase.sd(cl),hh.N(cl))...
        ));
    hh.EA.ChangeStock.PoorDecrMarkup{cl,1} = ... 
        NormalDist(Input.EA.ChangeStock.PoorDecrMarkup.mean(cl),...
        Input.EA.ChangeStock.PoorDecrMarkup.sd(cl),hh.N(cl));
    hh.EA.ChangeStock.BuyLarge{cl,1} = max(0,... 
        NormalDist(Input.EA.ChangeStock.BuyLarge.mean(cl),...
        Input.EA.ChangeStock.BuyLarge.sd(cl),hh.N(cl))...
        );
    hh.EA.ChangeStock.CS{cl,1}=zeros(hh.N(cl),1);

    hh.EA.RandomBuy.large.prob{cl,1}  = min(1,max(0,... 
        LogNormalDist(Input.EA.RandomBuy.large.prob.mean(cl),...
        Input.EA.RandomBuy.large.prob.sd(cl),hh.N(cl))...
        ));

    hh.EA.large.EEA.PreferredStock{cl,1} = zeros(hh.N(cl),1);
    hh.EA.large.EEA.PreferredShare{cl,1} = zeros(hh.N(cl),1);
    % This could be done more elegantly without loop probably...
    for h=1:hh.N(cl)
        hh.EA.large.EEA.PreferredStock{cl,1}(h) = max(0,...
            NormalDist(... (desc,inj,lit,cl)
                Input.EA.large.EEA.mean(...
                    hh.NI.Desc{cl,1}(h),(hh.NI.Inj{cl,1}(h)-.5)*2,hh.NI.Lit{cl,1}(h)+1,cl),...
                Input.EA.large.EEA.se(...
                    hh.NI.Desc{cl,1}(h),(hh.NI.Inj{cl,1}(h)-.5)*2,hh.NI.Lit{cl,1}(h)+1,cl),...
                1)...
            );

    hh.EA.large.EEA.PreferredShare{cl,1}(h) = max(0,min(1,...
            NormalDist(... (desc,inj,lit,cl)
                Input.EA.large.EEA_Share.mean(...
                    hh.NI.Desc{cl,1}(h),(hh.NI.Inj{cl,1}(h)-.5)*2,hh.NI.Lit{cl,1}(h)+1,cl),...
                Input.EA.large.EEA_Share.se(...
                    hh.NI.Desc{cl,1}(h),(hh.NI.Inj{cl,1}(h)-.5)*2,hh.NI.Lit{cl,1}(h)+1,cl),...
                1)...
            ));
    hh.EA.large.EEA.PreferredShare{cl,1}(h) =...
        hh.EA.large.EEA.PreferredShare{cl,1}(h)*Input.EA.scaleEEA;    
    end   
    
end % close cluster loop


switch assign_modes.EA
    case 1 % cluster-specific assignment
        disp('assign_modes.EA = 1 (cluster-specific assignment).');
        for cl = 1:hh.ClNumber 
            hh.EA.stock{cl,1} = max(hh.EA.MinimumStock{cl,1},round(...
                NormalDist(Input.EA.Stock.Mean(cl),Input.EA.Stock.sd(cl),hh.N(cl))...
                ));
        end
        
    case 2 % cluster- and category-specific assignment
        disp('assign_modes.EA = 2 (cluster- and category-specific assignment).');
        for cl = 1:hh.ClNumber
            for h=1:hh.N(cl) 
                cc = hh.cat.cat{cl,1}(h); % category of current hh
				hh.EA.stock{cl,1}(h,1) = max(hh.EA.MinimumStock{cl,1}(h),round(...
                    NormalDist(Input.Cat.EA.Stock.Mean(cc,cl),Input.Cat.EA.Stock.sd(cc,cl),1)...
                    ));
            end
        end
        
    otherwise
        error('assign_modes.EA=%.0f not defined. \nMust be 1 (cluster-specific) or 2 (cluster-type-specific).',...
            assign_modes.EA);
end

for cl=1:hh.ClNumber
    hh.EA.large.EEA.stock{cl,1} = max(hh.EA.large.MinimumStock{cl,1},...
        min(hh.EA.stock{cl,1}, ...
        round(hh.EA.large.EEA.PreferredStock{cl,1})...
        ));
    hh.EA.large.stock{cl,1} = max(hh.EA.large.MinimumStock{cl,1},...
        min(hh.EA.stock{cl,1},...
        round(hh.EA.large.EEA.PreferredStock{cl,1}...
        ./hh.EA.large.EEA.PreferredShare{cl,1})...
        ));
    
    % added to make sure stock and min stock is equal to large EAs as small EAs kicked out
    hh.EA.MinimumStock{cl,1} = hh.EA.large.MinimumStock{cl,1};    
    hh.EA.stock{cl,1} = hh.EA.large.stock{cl,1};

    hh.EA.large.share{cl,1} = hh.EA.large.stock{cl,1}./...
        hh.EA.stock{cl,1};
    hh.EA.large.EEA.share{cl,1} = hh.EA.large.EEA.stock{cl,1}./...
        hh.EA.large.stock{cl,1};
    
    % initial EEA assignment
    hh.EA.large.EEA.initial_share{cl,1} = hh.EA.large.EEA.share{cl,1};
    hh.EA.large.EEA.initial_stock{cl,1} = hh.EA.large.EEA.stock{cl,1};
    hh.EA.large.initial_stock{cl,1} = hh.EA.large.stock{cl,1};

end

%% set up buy variables of households
switch ip
    case 1
        
        hh.EA.Buy.large = hh.EA.stock;
        hh.EA.Buy.EEA = hh.EA.stock;
        hh.EA.Buy.total = hh.EA.stock;

        % set initial value to 0, period-specific update in EA_Reporting
        for cl = 1:hh.ClNumber
            hh.EA.Buy.large{cl,1}(:) = 0;
            hh.EA.Buy.EEA{cl,1}(:) = 0;
            hh.EA.Buy.total{cl,1}(:) = 0;
        end        
end

%% assign price for EEAs/ NonEEAs
% defined on hh even not a hh specific variable (in order to change it in BehavioristicAdjustment.m)
hh.EA.priceEEA = Input.EA.PriceEEA;
hh.EA.priceNonEEA = Input.EA.PriceEEA * (1/Input.EA.PricePremiumEEA);

%% calculate avg large EAs by category
% required for budget constraint HHs
for cl = 1:hh.ClNumber
	cat = hh.cat.cat{cl,1}; % category of current hh
	large_stock = hh.EA.large.stock{cl,1};
	mean_large_stock_category{cl,1} = accumarray(cat,large_stock, [], @mean);
end

mean_large_stock_cat = cell2mat(mean_large_stock_category);
hh.EA.large.MeanLargeEACat = reshape(mean_large_stock_cat,[hh.cat.number,hh.ClNumber]);

for cl = 1:hh.ClNumber   
    hh.EA.large.avg_stock_category{cl,1} = NaN(hh.N(cl),1);
    hh.EA.large.inital_stock{cl,1} = NaN(hh.N(cl),1); 
    hh.EA.large.budget_constrained{cl,1} = zeros(hh.N(cl),1);
 	hh.EA.large.outage{cl,1} = zeros(hh.N(cl),1);
 	hh.EA.large.essential_EA{cl,1} = zeros(hh.N(cl),1);
    
    for h=1:hh.N(cl) 
        cc = hh.cat.cat{cl,1}(h); % category of current hh
		hh.EA.large.avg_stock_category{cl,1}(h,1) = round(hh.EA.large.MeanLargeEACat(cc,cl));                      
    end
    hh.EA.large.inital_stock{cl,1} = hh.EA.large.stock{cl,1};
end

%% initialize changes for simulation
for cl = 1:hh.ClNumber
    hh.EA.large.EEA.stock_change{cl,1}= zeros(hh.N(cl),1); % stock change EEA   
    hh.EA.ChangePSbyElasticity{cl,1} = NaN(hh.N(cl),1); % Change preferred share by price elasticity
    hh.EA.large.EEA.Change_EEA_PS_Conv{cl,1}= zeros(hh.N(cl),1); % change in preferred EEA share by conversations
end

%% average preferred share of top 20% 
% used for intitutional (norms) campaigns
PS = cell2mat(hh.EA.large.EEA.PreferredShare);
PSsort = sort(PS(:),'descend');% Sort Descending
Top20 = PSsort(1:ceil(length(PSsort)*0.2));% Top20  
hh.EA.large.EEA.avgPSTop20 = mean(Top20);

%% Marginal effect literacy on preferred share (elasticity):
% currently zero, since not observed in data

for cl = 1:hh.ClNumber
    hh.EA.large.EEA.Elasticity_LitPS{cl,1} = 0;
end

% for cl = 1:hh.ClNumber
% 	lit = hh.NI.Lit{cl,1} + 1; % lit level (1-11 scale)
% 	ps_eea = hh.EA.large.EEA.PreferredShare{cl,1}; % preferred share
% 	mean_pseea_lit{cl,1} = accumarray(lit,ps_eea, [], @mean); % average PS by lit level
% end
% 
% for cl = 1:hh.ClNumber
% 	for lit = 2:11
%             % marginal effect literacy on preferred share by cl and lit
%             % level
% 			dxdy_LitPS{cl,1}(lit,1) = ...
%                 ((mean_pseea_lit{cl,1}(lit,1)...
%                     - mean_pseea_lit{cl,1}(lit-1,1))...
%                         /mean_pseea_lit{cl,1}(lit-1,1))...
%                 / (( lit - (lit-1))/(lit-1));
% 	end
% end
% 
% for cl = 1:hh.ClNumber
%     % (average) marginal effect by cl
% 	mean_dxdy_LitPS{cl,1} = mean(dxdy_LitPS{cl,1}(2:11,1));
% 	if mean_dxdy_LitPS{cl,1} > 0 % only take into account positive effect, set negative effect to zero
% 		hh.EA.large.EEA.Elasticity_LitPS{cl,1} = mean_dxdy_LitPS{cl,1};
% 	else
% 		hh.EA.large.EEA.Elasticity_LitPS{cl,1} = 0;
% 	end
% end

toc