function hh = EA_ChangeStock(hh,cl)
%EA_CHANGESTOCK determines if household changes stock of electric 
% appliances (-1, 0, +1) and what (small or large appliance) to dispose or
% to buy, respectively, and whether or not to choose an EEA (in case of 
% large).
%%%%%%%%%
% Input: hh structure
%%%%%%%%%
% Returns: hh structure

for h=1:hh.N(cl)
    % Increase or decrease total number of appliances (CS=0 set in Master)
    switch hh.large{cl,1}(h)
        case 1 % decide to change stock more frequently if large hh
            NewProb = (1+ hh.EA.ChangeStock.LargeFreq{cl,1}(h))...
                   * hh.EA.ChangeStock.prob{cl,1}(h);           
        case 0 % small hh
            NewProb = hh.EA.ChangeStock.prob{cl,1}(h);
    end
    switch hh.rich{cl,1}(h)
        case 1 % increase less likely if poor
            NewIncr = hh.EA.ChangeStock.increase{cl,1}(h);
        case 0
            NewIncr = (1-hh.EA.ChangeStock.PoorDecrMarkup{cl,1}(h)) ...
                * hh.EA.ChangeStock.increase{cl,1}(h);
    end

    if rand < NewProb
        if rand < NewIncr
            hh.EA.ChangeStock.CS{cl,1}(h) = 1;
        else 
            hh.EA.ChangeStock.CS{cl,1}(h) = -1;
        end
    end

    if hh.EA.stock{cl,1}(h)+hh.EA.ChangeStock.CS{cl,1}(h) ...
            < hh.EA.large.MinimumStock{cl,1}(h)
        hh.EA.ChangeStock.CS{cl,1}(h) = 0;
    end

    % update stocks and buy measures (keep >= 1, buy >= 0)
    if hh.EA.ChangeStock.CS{cl,1}(h)~=0
        % determine if EEA or non-EEA hit by hh.EA.ChangeStock.CS{cl,1}(h)
        changeEEA=(rand<hh.EA.large.EEA.PreferredShare{cl,1}(h));

        hh.EA.stock{cl,1}(h) = hh.EA.stock{cl,1}(h) ...
            + hh.EA.ChangeStock.CS{cl,1}(h);

        if rand < hh.EA.ChangeStock.BuyLarge{cl,1}(h)% Change # of large EAs
            if hh.EA.large.stock{cl,1}(h) + hh.EA.ChangeStock.CS{cl,1}(h) > ...
                    hh.EA.large.MinimumStock{cl,1}(h) 
                hh.EA.large.stock{cl,1}(h) = ...
                     hh.EA.large.stock{cl,1}(h) + hh.EA.ChangeStock.CS{cl,1}(h);
                hh.EA.large.EEA.stock{cl,1}(h) = min([...
                     hh.EA.large.EEA.stock{cl,1}(h)+...
                        changeEEA*hh.EA.ChangeStock.CS{cl,1}(h),...
                     hh.EA.large.stock{cl,1}(h)...
                     ]);
                 hh.EA.Buy.large{cl,1}(h) = max([0,...
                     hh.EA.Buy.large{cl,1}(h)+...
                     hh.EA.ChangeStock.CS{cl,1}(h)]);
                 hh.EA.Buy.EEA{cl,1}(h) = max([0,...
                     hh.EA.Buy.EEA{cl,1}(h)+...
                     changeEEA*hh.EA.ChangeStock.CS{cl,1}(h)]);

            % else: do not change large stock
            end

        end

        % update remaining variables
        hh.EA.stock{cl,1}(h) = ...
            hh.EA.large.stock{cl,1}(h);

    end % close if (change #)
    
end

end