function hh = EA_DecisionMaking(hh,NW,modes,options,ip)
%EA_DECISIONMAKING determines the number and kind of the electric 
% appliances each household replaces and determines with what these are
% going to be replaced.
%%%%%%%%%
% Input: hh structure, NW structure, modes and options structures, 
%   current ip
%%%%%%%%%
% Returns/updates: hh structure

% cluster loop
for cl=1:hh.ClNumber   

    % reset period-specific buy-measures 
    hh.EA.Buy.large{cl,1}(:) = 0;
    hh.EA.Buy.EEA{cl,1}(:) = 0;
    hh.EA.Buy.total{cl,1}(:) = 0;
        
    hh.EA.large.stock_previous_iter{cl,1} = hh.EA.large.stock{cl,1};
    hh.EA.large.EEA.stock_previous_iter{cl,1} = hh.EA.large.EEA.stock{cl,1};
     
                
    for h=1:hh.N(cl) % loop really necessary? Re-programming to vectors?
        % decide on number and kind of appliances to buy
        
        % NW effect
        switch modes.NW
            case 'active'
                BuyEEAProb = EA_NWeffect(...
                    hh.EA.large.EEA.PreferredShare{cl,1}(h),'Family',options,cl,NW,h);
            otherwise
                BuyEEAProb = hh.EA.large.EEA.PreferredShare{cl,1}(h);
        end
        
        % large appliances
        switch hh.owner{cl,1}(h)
            case 1 % Replace iteratively only if homeowner
                for s=1:hh.EA.large.stock{cl,1}(h)
                    if rand < 1/(...
                            hh.EA.large.RenewEvery{cl,1}(h)...
                            + (1 - hh.rich{cl,1}(h))...
                                *options.EA.large.REPoorChng...
                            )
                        hh.EA.Buy.large{cl,1}(h) = ...
                            hh.EA.Buy.large{cl,1}(h)+1;
                        hh.EA.Buy.EEA{cl,1}(h) = ...
                            hh.EA.Buy.EEA{cl,1}(h)...
                            + (rand<BuyEEAProb); 

                        % decide if replaced EA was EEA
                        hh.EA.large.EEA.stock{cl,1}(h) = max(0, ...
                            hh.EA.large.EEA.stock{cl,1}(h) ...
                            - (rand<hh.EA.large.EEA.share{cl,1}(h))...
                            ); 
                    end 
                end 

            case 0 % Renter
                % owner replaces 1:1, renter more at a time (as defined
                % by Cl.EA.large.RenterBulkSize); therefore check if 
                % buy>stock and adjust stock eventually
                CurrentBulkSize=round(...
                    hh.EA.large.RenterBulkShare{cl,1}(h)...
                    *hh.EA.large.stock{cl,1}(h)...
                    );
                % 1. for bulk part
                for s=1:CurrentBulkSize
                    if rand < 1/(...
                            hh.EA.large.RenewEvery{cl,1}(h)...
                            + ( 1 - hh.rich{cl,1}(h))...
                                *options.EA.large.REPoorChng...
                            )...
                            /CurrentBulkSize 
                        hh.EA.Buy.large{cl,1}(h) = ...
                            hh.EA.Buy.large{cl,1}(h)+...
                            round(CurrentBulkSize);
                        hh.EA.Buy.EEA{cl,1}(h) = ...
                            hh.EA.Buy.EEA{cl,1}(h)...
                            +(rand<BuyEEAProb)*round(CurrentBulkSize);
                        % decide if replaced EAs where EEAs
                        for bulk = 1:round(CurrentBulkSize)
                            hh.EA.large.EEA.stock{cl,1}(h) = max(0,...
                                min(hh.EA.large.stock{cl,1}(h), ...
                                hh.EA.large.EEA.stock{cl,1}(h) ...
                                - (rand<hh.EA.large.EEA.share{cl,1}(h))...
                                ));
                        end
                        break
                    end 
                end 
                
                % 2. for non-bulk-part (equal to iterative replacement from
                % above, "case 1")
                for s=CurrentBulkSize+1:hh.EA.large.stock{cl,1}(h)
                    if rand < 1/(...
                            hh.EA.large.RenewEvery{cl,1}(h)...
                            + (1 - hh.rich{cl,1}(h))...
                                *options.EA.large.REPoorChng...
                            )
                        hh.EA.Buy.large{cl,1}(h) = ...
                            hh.EA.Buy.large{cl,1}(h)+1;
                        hh.EA.Buy.EEA{cl,1}(h) = ...
                            hh.EA.Buy.EEA{cl,1}(h)...
                            + (rand<BuyEEAProb); 

                        % decide if replaced EA was EEA
                        hh.EA.large.EEA.stock{cl,1}(h) = max(0, ...
                            hh.EA.large.EEA.stock{cl,1}(h) ...
                            - (rand<hh.EA.large.EEA.share{cl,1}(h))...
                            ); 
                    end 
                end 


                hh.EA.large.stock{cl,1}(h) = max(...
                    hh.EA.Buy.large{cl,1}(h),...
                    hh.EA.large.stock{cl,1}(h));

                hh.EA.large.EEA.stock{cl,1}(h) = max(...
                    hh.EA.Buy.EEA{cl,1}(h),...
                    hh.EA.large.EEA.stock{cl,1}(h));

                hh.EA.stock{cl,1}(h) = hh.EA.large.stock{cl,1}(h);

            otherwise
                error('Error in EA_DecisionMaking. \nhh.owner{%.0f,1}(%.0f)=%.0f.\n(Must be 0 or 1.)',cl,h,hh.owner{cl,1}(h))
        end

    end

                
    switch options.EA.ChangeStock
        case 1
            hh = EA_ChangeStock(hh,cl);
    end

    switch options.EA.RandomBuy
        case 1
            hh = EA_RandomBuy(hh,cl);
    end
     
    
    
    % update of household measures: EEA and aggregate buy measures
    hh.EA.large.EEA.stock{cl,1} = min(hh.EA.large.stock{cl,1},...
        hh.EA.large.EEA.stock{cl,1} + hh.EA.Buy.EEA{cl,1});

    hh.EA.large.EEA.share{cl,1} = ...
        hh.EA.large.EEA.stock{cl,1} ./ hh.EA.large.stock{cl,1};
    hh.EA.large.share{cl,1} = ...
        hh.EA.large.stock{cl,1} ./ hh.EA.stock{cl,1};


    hh.EA.Buy.total{cl,1} = hh.EA.Buy.large{cl,1};    
    
    % change in EEA stock
    hh.EA.large.EEA.stock_change{cl,1} = ...
                        hh.EA.large.EEA.stock{cl,1}...
                        - hh.EA.large.EEA.stock_previous_iter{cl,1};
                                
   
    
     % EA_BudgetConstraint:
    switch options.EA.budget_constraint
 		case 1      
           for h=1:hh.N(cl)
                 % compare stock to inital stock to define if outage
                 if hh.EA.large.inital_stock{cl,1}(h) > hh.EA.large.stock_previous_iter{cl,1}(h)
                     hh.EA.large.outage{cl,1}(h) = 1; 
                 else
                     hh.EA.large.outage{cl,1}(h) = 0;
                 end
 
                 % compare stock to avg stock of same category to define if essential 
                 if hh.EA.large.avg_stock_category{cl,1}(h) > hh.EA.large.stock_previous_iter{cl,1}(h)
                     hh.EA.large.essential_EA{cl,1}(h) = 1; 
                 else
                     hh.EA.large.essential_EA{cl,1}(h) = 0;
                 end
           
    
                % define if EA to be replaced or not and if yes EEA or non EEA and how many	
                if hh.EA.large.budget_constrained{cl,1}(h) == 1 % if HH budget constrained; defined in BehavioristicAdjustment.m
                    if hh.EA.large.outage{cl,1}(h) == 1 % if EA outage
                        if hh.EA.large.essential_EA{cl,1}(h) == 1 % if EA is essential
                            % replace yes but only EA which failed (replace based on relative costs)                            
                            hh.EA.Buy.large{cl,1}(h) = ceil(hh.EA.large.avg_stock_category{cl,1}(h) - hh.EA.large.stock_previous_iter{cl,1}(h));
                            % EEA vs nonEEA? --> look at relative prices
                            if hh.EA.RelativeValuedCostsEEA{cl,1}(h) > 1 % EEA more expensive than NonEEA
                                hh.EA.Buy.EEA{cl,1}(h) = 0;
                            else % EEA cheaper than NonEEA
                                hh.EA.Buy.EEA{cl,1}(h) = hh.EA.Buy.large{cl,1}(h);
                            end
                        else  % if not essential do not repalce
                            hh.EA.Buy.large{cl,1}(h) = 0;
                            hh.EA.Buy.EEA{cl,1}(h) = 0;
                        end
                    else % if no outage do not buy EA as long as budget is constrained
                        hh.EA.Buy.large{cl,1}(h) = 0;
                        hh.EA.Buy.EEA{cl,1}(h) = 0;
                    end
                    % update stocks & shares
                    hh.EA.large.stock{cl,1}(h) = ...
                        hh.EA.large.stock_previous_iter{cl,1}(h) ...
                        + hh.EA.Buy.large{cl,1}(h);

                    hh.EA.large.EEA.stock{cl,1}(h) = ...
                        hh.EA.large.EEA.stock_previous_iter{cl,1}(h)...
                        + hh.EA.Buy.EEA{cl,1}(h);
                   

                    hh.EA.stock{cl,1}(h) = hh.EA.large.stock{cl,1}(h);
                    
                    hh.EA.large.EEA.share{cl,1}(h) = ...
                        hh.EA.large.EEA.stock{cl,1}(h) ./ hh.EA.large.stock{cl,1}(h);
                    hh.EA.large.share{cl,1}(h) = ...
                        hh.EA.large.stock{cl,1}(h) ./ hh.EA.stock{cl,1}(h);

                    hh.EA.Buy.total{cl,1}(h) = hh.EA.Buy.large{cl,1}(h); 

                        % change in EEA stock
                    hh.EA.large.EEA.stock_change{cl,1} = ...
                        hh.EA.large.EEA.stock{cl,1}...
                        - hh.EA.large.EEA.stock_previous_iter{cl,1};
                    
                end	
           end
    end
end 

end


   