function BuyEEAProb = EA_NWeffect(HHPreferredShare,SNW,options,cl,NW,h)
%EA_NWeffect determines for each hh (call from within hh-loop) by how much
% the probilility to buy EEA increases due to peer pressure from within 
% a pre-selected network.
%%%%%%%%%
% Input: HHPreferredShare, SNW: Selected NW (for influence), options
%   struct, cl number, NW struct, h: household
%%%%%%%%%
% Returns: BuyEEAProb: Probability to buy EEA

% decide on number and kind of appliances to buy
if isnan(NW.(SNW).ID{cl,1}(h,2)) % if only belonging to one NW
    BuyEEAProb = HHPreferredShare ...
        + options.NW.NWon ... evtl increase BuyEEAProb only if NW.NWon=1
            * (1 - HHPreferredShare) ... limit of PS
            * (options.NW.WeightPSMax...
                * NW.(SNW).EA.large.EEA.PreferredShareMax(...
                    NW.(SNW).ID{cl,1}(h,1))...
                + (1-options.NW.WeightPSMax)...
                    * NW.(SNW).EA.large.EEA.PreferredShare(...
                        NW.(SNW).ID{cl,1}(h,1))...
                ); % weighted avg of PSMax and avg PS of NW Family
else % if belonging to two NWs
    BuyEEAProb = HHPreferredShare ...
        + options.NW.NWon ...
            * (1 - HHPreferredShare) ...
            * max(... take higher weigthed avg (NW1 or NW2)
                (options.NW.WeightPSMax...
                    * NW.(SNW).EA.large.EEA.PreferredShareMax(...
                        NW.(SNW).ID{cl,1}(h,1))...
                    + (1-options.NW.WeightPSMax)...
                        * NW.(SNW).EA.large.EEA.PreferredShare(...
                        NW.(SNW).ID{cl,1}(h,1))...
                    ) ...
                ,(options.NW.WeightPSMax...
                    * NW.(SNW).EA.large.EEA.PreferredShareMax(...
                        NW.(SNW).ID{cl,1}(h,2))...
                    + (1-options.NW.WeightPSMax)...
                        * NW.(SNW).EA.large.EEA.PreferredShare(...
                        NW.(SNW).ID{cl,1}(h,2))...
                    ) ...
                );    
end

end