function Input = EA_Parameters(Input)
%EA_PARAMETERS Ad-hoc initial setup by cluster
%%%%%%%%%
% Input: Input structure
%%%%%%%%%
% Returns/updates: Input structure (mostly used in EA_AssignHH.m for
% agent-specific assignment; labeled if handled by Baseline_Definition.m)

%% Stock
% define minimum stock
Input.EA.MinimumStock.mean(1:5) = 4; 
Input.EA.MinimumStock.sd = (1/3).*Input.EA.MinimumStock.mean; 

% define probability to change stock
Input.EA.ChangeStock.prob.mean(1:Input.number,1) = 0.35;
Input.EA.ChangeStock.prob.sd(1:Input.number,1) = 0.17;

% define increase in stock
Input.EA.ChangeStock.increase.mean = [0.75 0.83 0.83 0.97 0.75];
Input.EA.ChangeStock.increase.sd = [0.08 0.07 0.07 0.07 0.07];

% Poor households decrease their stock more likely.
% PoorDecrMarkup is the size of the markup: (1-markup)* mean for poor 
Input.EA.ChangeStock.PoorDecrMarkup.mean(1:Input.number,1) = 0.25;
Input.EA.ChangeStock.PoorDecrMarkup.sd(1:Input.number,1) = 0.125;

% Probability of changing the number of large appliances 
Input.EA.ChangeStock.BuyLarge.mean(1:Input.number,1) = 0.38;
Input.EA.ChangeStock.BuyLarge.sd(1:Input.number,1) = 0.08;

% Large households change the size of their stock more frequently.
% Input.EA.ChangeStock.LargeFreqIncrease is the markup on the frequency.
Input.EA.ChangeStock.LargeFreqIncrease.mean(1:Input.number,1) = 0.5;
Input.EA.ChangeStock.LargeFreqIncrease.sd(1:Input.number,1) = .1;

%% Large
Input.EA.large.MinimumStock.mean = .5.*Input.EA.MinimumStock.mean;
Input.EA.large.MinimumStock.sd = (1/3).*Input.EA.large.MinimumStock.mean;
Input.EA.large.RenewEvery.mean = [7 7 8 8 9]; %[1 1 1 1 1]; %
Input.EA.large.RenewEvery.sd = [1 1 1 1 1]; %[0 0 0 0 0]; %

% change of RenewEvery, if hh poor (if positive: increase of RE.mean)
Input.EA.large.RenewEveryPoorChng = 2; % handled by Baseline_Definition.m

% Renters replace a share of their large EAs as a bulk. (Motivation: e.g.
% relocation, all-new-kitchen) The owner replaces more likel 1:1. 
Input.EA.large.RenterBulkShare.mean(1:Input.number,1) = .5; 
Input.EA.large.RenterBulkShare.sd(1:Input.number,1) = .2; 


%% Buy
Input.EA.RandomBuy.large.prob.mean(1:Input.number,1) = .1;
Input.EA.RandomBuy.large.prob.sd(1:Input.number,1) = 0.5*Input.EA.RandomBuy.large.prob.mean;

%% Channels
Input.EA.YearsIntroLabel = 15; % define years since when labels exist
% handled by Baseline_Definition.m

%% Prices
Input.EA.PriceEEA = 1500; %price per EEA (own assumtion)

% price trend historic EA: based on Landesindex der Konsumentenpreise 2008-2017
% EEA:
Input.EA.TrendPriceEEA(1)= 0 ; 
Input.EA.TrendPriceEEA(2)= 21; 
Input.EA.TrendPriceEEA(3)= -16; 
Input.EA.TrendPriceEEA(4)= 3; 
Input.EA.TrendPriceEEA(5)= -52; 
Input.EA.TrendPriceEEA(6)= -61; 
Input.EA.TrendPriceEEA(7)= -41; 
Input.EA.TrendPriceEEA(8)= -99; 
Input.EA.TrendPriceEEA(9)= -64; 
Input.EA.TrendPriceEEA(10)= -48; 

% NonEEA:
Input.EA.TrendPriceNonEEA(1)=  0; 
Input.EA.TrendPriceNonEEA(2)=  19; 
Input.EA.TrendPriceNonEEA(3)=  -15; 
Input.EA.TrendPriceNonEEA(4)=  3; 
Input.EA.TrendPriceNonEEA(5)=  -46; 
Input.EA.TrendPriceNonEEA(6)=  -54; 
Input.EA.TrendPriceNonEEA(7)=  -37; 
Input.EA.TrendPriceNonEEA(8)=  -88; 
Input.EA.TrendPriceNonEEA(9)=  -57; 
Input.EA.TrendPriceNonEEA(10)=  -43; 

% price trend future EA: historic trend continued
% EEA:
Input.EA.FutureTrendPriceEEA(1)=0;
Input.EA.FutureTrendPriceEEA(2)=-397;
Input.EA.FutureTrendPriceEEA(3)=-40;
Input.EA.FutureTrendPriceEEA(4)=-40;
Input.EA.FutureTrendPriceEEA(5)=-40;
Input.EA.FutureTrendPriceEEA(6)=-40;
Input.EA.FutureTrendPriceEEA(7)=-40;
Input.EA.FutureTrendPriceEEA(8)=-40;
Input.EA.FutureTrendPriceEEA(9)=-40;
Input.EA.FutureTrendPriceEEA(10)=-40;

% NonEEA:
Input.EA.FutureTrendPriceNonEEA(1)=0;
Input.EA.FutureTrendPriceNonEEA(2)=-354;
Input.EA.FutureTrendPriceNonEEA(3)=-35;
Input.EA.FutureTrendPriceNonEEA(4)=-35;
Input.EA.FutureTrendPriceNonEEA(5)=-35;
Input.EA.FutureTrendPriceNonEEA(6)=-35;
Input.EA.FutureTrendPriceNonEEA(7)=-35;
Input.EA.FutureTrendPriceNonEEA(8)=-35;
Input.EA.FutureTrendPriceNonEEA(9)=-35;
Input.EA.FutureTrendPriceNonEEA(10)=-35;

% Impact of relative cost on preferred EEA share:
% poor = 0.25, rich = 0.1 --> own assumption
Input.EA.ShifterEEAPS_Cost = [0.25 0.1];

% Price elasticity EA: 
% empirical research suggests that the price elasticity of demand for household energy-consuming appliances
% is in the range of -0.5 to -2. For labeled appliances between -0.55 and -2.8. 
% See https://www.sciencedirect.com/science/article/pii/S0140988311001587
% -1.675 = average of -0.55 and -2.8
Input.EA.PriceElasticityEA = -1.675; 

% Price premium EEA:
% In avg. 12% higher price for EEA compared to NonEEA
%as shown for the Spanish market by
% https://www.sciencedirect.com/science/article/pii/S0140988311001587 = 15.6% EEA premium 
% and 
% https://www.sciencedirect.com/science/article/pii/S095965261100237X = 8.9% EEA premium
Input.EA.PricePremiumEEA = 1.12; % EEAs are 12% more expensive as NonEEAs

% Lifetime
Input.EA.lifetimeEA = 8; % lifetime of EAs. Own assumptions

% Scaling of Preferred Share of EEA (for test purposes only):
% if 1, than multiplication by 1 (= no scaling)
Input.EA.scaleEEA = 1;
