function EA_Plot(hh,report,SimName,ip)
%EA_PLOT uses hh and report structures to plot figures on EA
%%%%%%%%%
% Input: hh and report structures, ip counter
%%%%%%%%%
% Returns: Figures, saved in results folder

% get colormap
rgb(1,:)= [0,0,0];
rgb(2,:)= HInt2RGB(1,100); % red, darkest
rgb(3,:)= HInt2RGB(7,82); % cyan, less dark
rgb(4,:)= HInt2RGB(3,64); % green, less dark
rgb(5,:)= HInt2RGB(9,46); % magenta, less dark
rgb(6,:)= HInt2RGB(2,28); % orange, less dark
rgb(7,:)= HInt2RGB(7,10); % blue cyan, lightest

figure;
% General plot
subplot(2,1,1);
hold on;
plot(report.EA.Stock.large(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
plot(report.EA.Stock.large_EEA(1:ip), 'LineWidth',2, 'LineStyle','--', 'Color',rgb(1,:),'HandleVisibility','off');
plot(report.EA.Buy.large(1:ip), 'LineWidth',2, 'Color',rgb(2,:));
plot(report.EA.Buy.large_EEA(1:ip), 'LineWidth',2, 'LineStyle','--', 'Color',rgb(2,:),'HandleVisibility','off');
title('LEA (solid) and EEA (dashed)');
xlabel('Time')
legend({'Stock','Newly bought'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
hold off;

subplot(2,1,2);
hold on;
plot(report.EA.Buy.large_EEA(1:ip)./report.EA.Buy.large(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
title('Share of bought EEA on bought LEA');
xlabel('Time')
hold off;

name=[SimName,'_EA_aggregate'];
print([pwd '\results\simulation\' name],'-dpng');


figure;
% Cluster-specific plot
subplot(2,1,1);
hold on;
plot(report.EA.Stock.large(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
plot(report.EA.Stock.large_EEA(1:ip), 'LineWidth',2, 'LineStyle','--', 'Color',rgb(1,:),'HandleVisibility','off');
for cl=1:hh.ClNumber
    plot(report.Cl.EA.Stock.large(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
    plot(report.Cl.EA.Stock.large_EEA(1:ip,cl), 'LineWidth',1, 'LineStyle','--', 'Color',rgb(cl+1,:),'HandleVisibility','off');
end
title('LEA (solid) and EEA (dashed)');
xlabel('Time')
% legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
%     ,'Location','southoutside'...
%     ,'Orientation','horizontal'...
%     ,'FontSize',8 ...
%     );
hold off;

subplot(2,1,2);
hold on;
plot(report.EA.Buy.large_EEA(1:ip)./report.EA.Buy.large(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.EA.Buy.large_EEA(1:ip,cl)./report.Cl.EA.Buy.large(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
title('Share of bought EEA on bought LEA');
xlabel('Time')

leg=legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03]; 
%[left bottom width height] lb: distance from lower left corner, wh: dimensions
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off;

name=[SimName,'_EA_by_cluster'];
print([pwd '\results\simulation\' name],'-dpng');

end