function hh = EA_RandomBuy(hh,cl)
%EA_RANDOMBUY determines if household buys each of its large appliances
% randomly, i.e., not following a rational pattern. (Imprecise, since 
% decision if randombuy replaces an EEA is based on probability rather than
% real logic. See comment in code.
%%%%%%%%%
% Input: hh structure
%%%%%%%%%
% Returns: hh structure

% random buy 
for h=1:hh.N(cl)
    % for every large appliance
    for r = 1:hh.EA.Buy.large{cl,1}(h)

        % if randombuy
        if rand<hh.EA.RandomBuy.large.prob{cl,1}(h)

            % decide if randombuy is an EEA
            if rand<0.5

                % decide if randombuy replaces an EEA 
                % NOTE: This dynamic condition implies that even if a household
                % replaces the number of items it has each period and if it 
                % replaces it with only EEA, it does not imply that the share
                % of EEA is 1 after one period. The reason is that it replaces
                % some of the just acquired appliances right after buying it, 
                % i.e., in the same period. But this implies that the household
                % might well keep some of the (older) non-EEA for quite some
                % time. For more realistic scales of RandomBuy this effect
                % causes less "distortion" since the effect can be thought of 
                % being more random.
                if rand<hh.EA.Buy.EEA{cl,1}(h)...
                        / hh.EA.Buy.large{cl,1}(h)
                    % nothing changes
                else % EEA replaces non-EEA
                    hh.EA.Buy.EEA{cl,1}(h) = min( ...
                        hh.EA.Buy.large{cl,1}(h), ...
                        hh.EA.Buy.EEA{cl,1}(h)+1);
                end

            else % randombuy is a non-EEA
                if rand<hh.EA.Buy.EEA{cl,1}(h)...
                        / hh.EA.Buy.large{cl,1}(h)
                    hh.EA.Buy.EEA{cl,1}(h) = max(0, ...
                        hh.EA.Buy.EEA{cl,1}(h)-1);
                % else non-EEA replaces non-EEA and nothing changes
                end

            end

        end % if randombuy

    end % for every large appliance
end

end