function report = EA_Reporting(hh, report, ip, maxiter)
%EA_REPORTING Reporting of period-specific EA measures on the aggregate, 
% cluster and individual level.
%%%%%%%%%
% Input: hh structure, report structure, ip, and maxiter [opt]
%%%%%%%%%
% Returns: report structure

N=sum(hh.N); 

switch ip
    case 1 % initial period
        disp('EA Reporting for initial setup.')
        % Use initial period to setup reporting structure
        % Aggregate EA reporting measures
        % Avg stock of appliances
        report.EA.Stock.total = NaN(maxiter+1,1);
        report.EA.Stock.large = report.EA.Stock.total;
        report.EA.Stock.large_EEA = report.EA.Stock.total;
        report.EA.large_EEA_share = report.EA.Stock.total;

        % Change of stock
        report.EA.Buy.total = report.EA.Stock.total;
        report.EA.Buy.large = report.EA.Stock.total;
        report.EA.Buy.large_EEA = report.EA.Stock.total;

        
        % EA reporting measures by cluster
        % Stock of appliances
        report.Cl.EA.Stock.total = NaN(maxiter+1,hh.ClNumber);
        report.Cl.EA.Stock.large = report.Cl.EA.Stock.total;
        report.Cl.EA.Stock.large_EEA = report.Cl.EA.Stock.total;
        report.Cl.EA.large_EEA_share = report.Cl.EA.Stock.total;

        % Change of stock
        report.Cl.EA.Buy.total = report.Cl.EA.Stock.total;
        report.Cl.EA.Buy.large = report.Cl.EA.Stock.total;
        report.Cl.EA.Buy.large_EEA = report.Cl.EA.Stock.total;

        
        % Individual EA reporting measures
        report.hh.EA.stock{hh.ClNumber,maxiter+1} = 0;
        report.hh.EA.large = report.hh.EA.stock;
        report.hh.EA.large_EEA = report.hh.EA.stock;
        report.hh.EA.essential_EA= report.hh.EA.stock;
        report.hh.EA.outage= report.hh.EA.stock;
        report.hh.EA.Buy.large= report.hh.EA.stock;
        report.hh.EA.Buy.EEA= report.hh.EA.stock;
        report.hh.EA.large_EEA_change= report.hh.EA.stock;
        report.hh.EA.large_EEA_share= report.hh.EA.stock;
        
                

    otherwise % for ip > 1
                        
        % Change of stock
        % ... aggregate
        report.EA.Buy.large(ip) = sum(cell2mat(hh.EA.Buy.large))/N;
        report.EA.Buy.large_EEA(ip) = sum(cell2mat(hh.EA.Buy.EEA))/N;
        report.EA.Buy.total(ip) = sum(cell2mat(hh.EA.Buy.total))/N;
         

        
         % ... by cluster
        for cl=1:hh.ClNumber 
            report.Cl.EA.Buy.large(ip,cl) = sum(...
                hh.EA.Buy.large{cl,1}(:) ...
                )/hh.N(cl);
            report.Cl.EA.Buy.large_EEA(ip,cl) = sum(...
                hh.EA.Buy.EEA{cl,1}(:) ...
                )/hh.N(cl);
            report.Cl.EA.Buy.total(ip,cl) = sum(...
                hh.EA.Buy.total{cl,1}(:) ...
                )/hh.N(cl);                        
        end

end


% Stock of appliances
% ... aggregate
report.EA.Stock.total(ip) = sum(cell2mat(hh.EA.stock))/N;
report.EA.Stock.large(ip) = sum(cell2mat(hh.EA.large.stock))/N;
report.EA.Stock.large_EEA(ip) = sum(cell2mat(hh.EA.large.EEA.stock))/N;
report.EA.large_EEA_share(ip) = sum(cell2mat(hh.EA.large.EEA.share))/N;

% ... by cluster
for cl=1:hh.ClNumber
    report.Cl.EA.Stock.total(ip,cl) = sum(hh.EA.stock{cl,1}(:))/hh.N(cl);
    report.Cl.EA.Stock.large(ip,cl) = sum(hh.EA.large.stock{cl,1}(:))/hh.N(cl);
    report.Cl.EA.Stock.large_EEA(ip,cl) = sum(hh.EA.large.EEA.stock{cl,1}(:))/hh.N(cl);
    report.Cl.EA.large_EEA_share(ip,cl) = sum(hh.EA.large.EEA.share{cl,1}(:))/hh.N(cl); 
end

% Individual EA reporting measures
for cl=1:hh.ClNumber
    report.hh.EA.stock{cl,ip} = hh.EA.stock{cl,1};
    report.hh.EA.large{cl,ip} = hh.EA.large.stock{cl,1};
    report.hh.EA.large_EEA{cl,ip} = hh.EA.large.EEA.stock{cl,1};    
    report.hh.EA.essential_EA{cl,ip} = hh.EA.large.essential_EA{cl,1};
    report.hh.EA.outage{cl,ip} = hh.EA.large.outage{cl,1};
    report.hh.EA.Buy.large{cl,ip} = hh.EA.Buy.large{cl,1};
    report.hh.EA.Buy.EEA{cl,ip} = hh.EA.Buy.EEA{cl,1};    
    report.hh.EA.large_EEA_change{cl,ip}  = hh.EA.large.EEA.stock_change{cl,1};    
    report.hh.EA.large_EEA_share{cl,ip} = hh.EA.large.EEA.share{cl,1};    
end    

end