function hh = EU_DecisionMaking(hh,NW,EUold,options)
%EU_DECISIONMAKING determines the electricity use by production function
%%%%%%%%%
% Input: hh structure, NW structure, EUold [by cl], options structure
%%%%%%%%%
% Returns/updates: hh structure


%% Derive EU level

% derive EU level based on stockEA, shareEEA or NonEEA, base EU
% of EEA or NonEEA, utilisation from effort and fix calibration factor. 
% Sofar, familysize not considered        
for cl=1:hh.ClNumber
    switch options.EU.TrendEU
        
        case 0 % no trend in EU considered
            
            % new EU level
            hh.EU.level{cl,1} = ...
                hh.EA.large.stock{cl,1}...
                    .*(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1})...
                    .*hh.EU.mean_Base_EEA...
                    .*hh.EU.Effort{cl,1}...
                    .*hh.EU.eu_calibrationfactor{cl,1}...
                + hh.EA.large.stock{cl,1}...
                    .*(1-(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1}))...
                    .*hh.EU.mean_Base_NONEEA...
                    .*hh.EU.Effort{cl,1}...
                    .*hh.EU.eu_calibrationfactor{cl,1};
                
        case 1 % trend in EU considered
            
            % EU of previous iteration
            hh.EU.level_previous_iter{cl,1} = hh.EU.level{cl,1};
            hh.EU.levelnew_previous_iter{cl,1} = hh.EU.levelnew{cl,1};         
            
            % new EU level
            hh.EU.levelnew{cl,1} = ...
                hh.EA.large.stock{cl,1}...
                    .*(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1})...
                    .*hh.EU.mean_Base_EEA...
                    .*hh.EU.Effort{cl,1}...
                    .*hh.EU.eu_calibrationfactor{cl,1}...
                + hh.EA.large.stock{cl,1}...
                    .*(1-(hh.EA.large.EEA.stock{cl,1}./ hh.EA.large.stock{cl,1}))...
                    .*hh.EU.mean_Base_NONEEA...
                    .*hh.EU.Effort{cl,1}...
                    .*hh.EU.eu_calibrationfactor{cl,1};
            
           % EU = previous EU * (1 + trend) + change EU (due to change in EEA or Effort)     
           hh.EU.level{cl,1} = hh.EU.level_previous_iter{cl,1}...
                                .* (1 + options.EU.TrendEU_ChangeYear)...
                                + (hh.EU.levelnew{cl,1} - hh.EU.levelnew_previous_iter{cl,1});
                            
            
    end
    
    hh.EU.ln{cl,1}=log(hh.EU.level{cl,1});

end

end