function EU_Plot(hh,report,SimName,ip)
%EU_PLOT uses hh and report structures to plot figures on EU
%%%%%%%%%
% Input: hh and report structures, ip counter
%%%%%%%%%
% Returns: Figures, saved in results folder

% get colormap
rgb(1,:)= [0,0,0];
rgb(2,:)= HInt2RGB(1,100); % red, darkest
rgb(3,:)= HInt2RGB(7,82); % cyan, less dark
rgb(4,:)= HInt2RGB(3,64); % green, less dark
rgb(5,:)= HInt2RGB(9,46); % magenta, less dark
rgb(6,:)= HInt2RGB(2,28); % orange, less dark
rgb(7,:)= HInt2RGB(7,10); % blue cyan, lightest

%% EU level: average and by cluster
figure;
plot(report.EU.level(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
title('Electricity usage (in kWh per household)');
xlabel('Time')
name=[SimName,'_EU'];
print([pwd '\results\simulation\' name],'-dpng');

figure;
hold on
plot(report.EU.level(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.EU.level(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
title('Electricity usage by cluster (in kWh per household)');
xlabel('Time')

leg=legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03];
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off
name=[SimName,'_EU_by_cluster'];
print([pwd '\results\simulation\' name],'-dpng');



%% boxplots EU: all HHs and by cluster

% --------------- over all HHs ------------------------
% write all HHs to sinlge vector
for ips = 1:10
	EUlevel{ips,1} = [report.hh.EU.level{1,ips};...
				 report.hh.EU.level{2,ips};...
				 report.hh.EU.level{3,ips};...
				 report.hh.EU.level{4,ips};...
				 report.hh.EU.level{5,ips}...
			   ];	
end

% group by iteration
group = [    ones(size(EUlevel{1,1}));
         2 * ones(size(EUlevel{2,1}));
         3 * ones(size(EUlevel{3,1}));
         4 * ones(size(EUlevel{4,1}));
         5 * ones(size(EUlevel{5,1}));
         6 * ones(size(EUlevel{6,1}));
         7 * ones(size(EUlevel{7,1}));
         8 * ones(size(EUlevel{8,1}));
         9 * ones(size(EUlevel{9,1}))
         10 * ones(size(EUlevel{10,1}))];

% create boxplot
figure
h = boxplot([EUlevel{1,1}; EUlevel{2,1}; EUlevel{3,1};...
             EUlevel{4,1}; EUlevel{5,1}; EUlevel{6,1};...
             EUlevel{7,1}; EUlevel{8,1}; EUlevel{9,1};...
             EUlevel{10,1}...
             ]...
             ,group...
            );
%set(h(7,:),'Visible','off'); % do not show outliers
title('Elec usage (in kWh/year - all HHs)')
xlabel('Time')
%ylim([-100 10000])
hold on
% add mean to boxplot (in addition to median)
plot([mean(EUlevel{1,1}); mean(EUlevel{2,1}); mean(EUlevel{3,1});...
        mean(EUlevel{4,1}); mean(EUlevel{5,1}); mean(EUlevel{6,1});...
        mean(EUlevel{7,1}); mean(EUlevel{8,1}); mean(EUlevel{9,1});...
        mean(EUlevel{10,1})...
      ]...
        ,'.k'...
     );
hold off
legend('mean','Location','northwest','Orientation','horizontal')
name=[SimName,'_EU_boxplot'];
print([pwd '\results\simulation\' name],'-dpng');


% --------------- by cluster ---------------------------
% loop over clusters
for cl = 1:5
    for ips = 1:10
        EUlevelCl{ips,cl} = [report.hh.EU.level{cl,ips}...
                   ];   
    end

    % group by iteration
    group = [    ones(size(EUlevelCl{1,cl}));
             2 * ones(size(EUlevelCl{2,cl}));
             3 * ones(size(EUlevelCl{3,cl}));
             4 * ones(size(EUlevelCl{4,cl}));
             5 * ones(size(EUlevelCl{5,cl}));
             6 * ones(size(EUlevelCl{6,cl}));
             7 * ones(size(EUlevelCl{7,cl}));
             8 * ones(size(EUlevelCl{8,cl}));
             9 * ones(size(EUlevelCl{9,cl}))
             10 * ones(size(EUlevelCl{10,cl}))];

    % create boxplot by cluster
    subplot(3,2,cl);
    hold on;
    h = boxplot([EUlevelCl{1,cl}; EUlevelCl{2,cl}; EUlevelCl{3,cl};...
                 EUlevelCl{4,cl}; EUlevelCl{5,cl}; EUlevelCl{6,cl};...
                 EUlevelCl{7,cl}; EUlevelCl{8,cl}; EUlevelCl{9,cl};...
                 EUlevelCl{10,cl}...
                 ]...
                 ,group...
                );
%    set(h(7,:),'Visible','off'); % do not show outliers
    title(sprintf('EU Cluster %d (KWh/year)',cl))
    xlabel('Time')
%    ylim([-100 10000])
    hold on
    % add mean to boxplot (in addition to median)
    plot([mean(EUlevelCl{1,cl}); mean(EUlevelCl{2,cl}); mean(EUlevelCl{3,cl});...
            mean(EUlevelCl{4,cl}); mean(EUlevelCl{5,cl}); mean(EUlevelCl{6,cl});...
            mean(EUlevelCl{7,cl}); mean(EUlevelCl{8,cl}); mean(EUlevelCl{9,cl});...
            mean(EUlevelCl{10,cl})...
          ]...
            ,'.k'...
         );
    hold off
    hold off
end


legend('mean','Location','northwest','Orientation','horizontal')
name=[SimName,'_EU_boxplot_by_Cluster'];
print([pwd '\results\simulation\' name],'-dpng');


%% EU Effort: average and by cluster
figure;
plot(report.EU.Effort(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
title('EU Effort');
xlabel('Time')
name=[SimName,'_EU_Effort'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');

figure;
hold on
plot(report.EU.Effort(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.EU.Effort(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
title('EU Effort by cluster');
xlabel('Time')

leg=legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03];
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off
name=[SimName,'_EU_Effort_by_cluster'];
print([pwd '\results\simulation\' name],'-dpng');

%% Change in EU level
plotEU.change=NaN(ip,1);
plotEU.clchange=NaN(ip,cl);
plotEU.change(2:ip)=(report.EU.level(2:ip)./report.EU.level(1:ip-1)-1).*100;
plotEU.clchange(2:ip,:)=(report.Cl.EU.level(2:ip,:)./report.Cl.EU.level(1:ip-1,:)-1).*100;

figure;
subplot(2,1,1);
hold on;
plot(report.EU.level(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.EU.level(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
title('Electricity usage by cluster (in kWh per household)');
xlabel('Time')
hold off

subplot(2,1,2);
hold on;
plot(plotEU.change(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(plotEU.clchange(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
title('Change of electricity usage by cluster (in %)');
xlabel('Time')

leg=legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03]; 
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off
name=[SimName,'_EU_change_by_cluster'];
print([pwd '\results\simulation\' name],'-dpng');

clearvars name leg plotEU

end