function report = EU_Reporting(hh, report, ip, maxiter)
%EU_REPORTING Reporting of period-specific EU measures on the aggregate, 
% cluster and individual level.
%%%%%%%%%
% Input: hh structure, report structure, ip, and maxiter [opt]
%%%%%%%%%
% Returns: report structure

N=sum(hh.N); 

switch ip
    case 1 % initial period
        disp('EU Reporting for initial setup.')
        % Use initial period to setup reporting structure
        % Aggregate EU reporting measures
        report.EU.ln = NaN(maxiter+1,1);
        report.EU.level = report.EU.ln;
        report.EU.Effort = report.EU.ln;
        
        % EU reporting measures by cluster
        report.Cl.EU.ln = NaN(maxiter+1,hh.ClNumber);
        report.Cl.EU.level = report.Cl.EU.ln;
        report.Cl.EU.Effort = report.Cl.EU.ln;

        % Individual eu reporting measures
        report.hh.EU.ln{hh.ClNumber,maxiter+1} = 0;
        report.hh.EU.level = report.hh.EU.ln;
        report.hh.EU.Effort = report.hh.EU.ln;
        
end

% EU reporting
% ... aggregate
report.EU.ln(ip) = sum(cell2mat(hh.EU.ln))/N;
report.EU.level(ip) = sum(cell2mat(hh.EU.level))/N;
report.EU.Effort(ip) = sum(cell2mat(hh.EU.Effort))/N;

for cl=1:hh.ClNumber 
    % ... cluster
    report.Cl.EU.ln(ip,cl)=sum(hh.EU.ln{cl,1}(:)/hh.N(cl));
    report.Cl.EU.level(ip,cl)=sum(hh.EU.level{cl,1}(:)/hh.N(cl));
    report.Cl.EU.Effort(ip,cl)=sum(hh.EU.Effort{cl,1}(:)/hh.N(cl));
    
    % ... individuum
    report.hh.EU.ln{cl,ip} = hh.EU.ln{cl,1};
    report.hh.EU.level{cl,ip} = hh.EU.level{cl,1};
    report.hh.EU.Effort{cl,ip} = hh.EU.Effort{cl,1};
   
end

end