function Histogram_byc(byc,forc,datadesc,data,hh)
%HISTOGRAM_BYC(byc,forc,datadesc,data,hh) Creates histogram by cat or cl
% byc = 1 -> by category, for cluster forc
% byc = 2 -> by cluster, for category forc
% forc = 'all' gives histogram for all clusters or categories, respectively
% datadesc -> data name/description as used for title and saving
% data -> data struct from which to plot histogram
% hh -> household struct (used for data selection)

% get colormap
rgb(1,:)= [0,0,0];
rgb(2,:)= HInt2RGB(1,100); % red, darkest
rgb(3,:)= HInt2RGB(7,82); % cyan, less dark
rgb(4,:)= HInt2RGB(3,64); % green, less dark
rgb(5,:)= HInt2RGB(9,46); % magenta, less dark
rgb(6,:)= HInt2RGB(2,28); % orange, less dark
rgb(7,:)= HInt2RGB(7,10); % blue cyan, lightest
rgb(8,:)= HInt2RGB(9,20); % , lightest

rgb(9:15,:)= rgb(2:8,:); % repeat color code

switch forc
    case 'all'
        switch byc
            case 1 % by category byc, for all clusters
                name = sprintf('Histogram of %s by category',datadesc);
                try
                    alldata = cell2mat(data');
                catch
                    alldata = cell2mat(data);
                end
                allhhcat = cell2mat(hh.cat.cat);
                figure
                hold on
                if numel(unique(data{1,1}))<10
                    bins = numel(unique(data{1,1}));
                    for cate=1:hh.cat.number
                        histogram(alldata(allhhcat==cate),...
                            'Normalization','count','NumBins',bins,...
                            'edgecolor',rgb(1+cate,:),'facealpha',.25,...
                            'facecolor',rgb(1+cate,:),'LineWidth',2)
                    end
                else
                    for cate=1:hh.cat.number
                        histogram(alldata(allhhcat==cate),...
                            'Normalization','count',...
                            'edgecolor',rgb(1+cate,:),'facealpha',.25,...
                            'facecolor',rgb(1+cate,:),'LineWidth',2)
                    end
                end
                if hh.cat.number == 8
                    legend({'cat1','cat2','cat3','cat4','cat5','cat6','cat7','cat8'})
                else
                    legend('show')
                end
                title(name)
                hold off

            case 2 % by cluster byc, for all categories
                name = sprintf('Histogram of %s by cluster',datadesc);
                figure
                hold on
                if numel(unique(data{1,1}))<10
                    bins = numel(unique(data{1,1}));
                    for clu=1:hh.ClNumber
                        histogram(data{clu,1}(:),...
                            'Normalization','count','NumBins',bins,...
                            'edgecolor',rgb(1+clu,:),'facealpha',.25,...
                            'facecolor',rgb(1+clu,:),'LineWidth',2)
                    end
                else
                    for clu=1:hh.ClNumber
                        histogram(data{clu,1}(:),...
                            'Normalization','count',...
                            'edgecolor',rgb(1+clu,:),'facealpha',.25,...
                            'facecolor',rgb(1+clu,:),'LineWidth',2)
                    end
                end
                if hh.ClNumber==5
                    legend({'Cl1','Cl2','Cl3','Cl4','Cl5'})
                else 
                    legend('show')
                end
                title(name)
                hold off

            otherwise
                disp('No valid byc.');
                disp('Must be 1 (by category) or 2 (by cluster).');
        end
        
    otherwise
        switch byc
            case 1 % by category byc, for cluster forc
                if forc>hh.ClNumber
                    error('forc=%.0f exceeds number of clusters hh.ClNumber=%.0f.',forc,hh.ClNumber);
                end
                name = sprintf('Histogram of %s for Cluster %.0f',datadesc,forc);
                figure
                hold on
                %bins = numel(unique(data{1,1}));
                for cate=1:hh.cat.number
                    histogram(data{forc,1}(hh.cat.cat{forc,1}==cate),...
                        'Normalization','count',...
                        'edgecolor',rgb(1+cate,:),'facealpha',.25,...
                        'facecolor',rgb(1+cate,:),'LineWidth',2)
                end
                if hh.cat.number == 8
                    legend({'cat1','cat2','cat3','cat4','cat5','cat6','cat7','cat8'})
                else
                    legend('show')
                end
                title(name)
                hold off

            case 2 % by cluster byc, for category forc
                if forc>hh.cat.number
                    error('forc=%.0f exceeds number of categories hh.cat.number=%.0f.',forc,hh.cat.number);
                end
                name = sprintf('Histogram of %s for Category %.0f',datadesc,forc);
                figure
                hold on
                %bins = numel(unique(data{1,1}));
                for clu=1:hh.ClNumber
                    histogram(data{clu,1}(hh.cat.cat{clu,1}==forc),...
                        'Normalization','count',...
                        'edgecolor',rgb(1+clu,:),'facealpha',.25,...
                        'facecolor',rgb(1+clu,:),'LineWidth',2)
                end
                if hh.ClNumber==5
                    legend({'Cl1','Cl2','Cl3','Cl4','Cl5'})
                else 
                    legend('show')
                end
                title(name)
                hold off

            otherwise
                disp('No valid byc.');
                disp('Must be 1 (by category) or 2 (by cluster).');
        end

end


name=strrep(name,'.','_');
name=strrep(name,' ','_');
print([pwd '\results\' name],'-dpdf','-bestfit');

end
