function report = ID_ConvReport(PM,hh,ID,options,report,ip)
%ID_ConvReport Save conversation structure and implied changes
%%%%%%%%%
% Input
% PM: Mode of PickingMates (by NW, by Cl or at random)
% hh, ID, options structures
% ip: iteration period to store period-specific info
%%%%%%%%%
% Returns: Report structure, with options field

        
% descriptive statistics structs
report.ID.(PM).Num.Total(1,ip) = numel(ID.(PM).Topic); % total number
report.ID.(PM).Num.TopicEA(1,ip) = sum(ID.(PM).Topic==1); % EA convs
report.ID.(PM).Num.TopicEU(1,ip) = sum(ID.(PM).Topic==2); % EU convs
report.ID.(PM).Num.TopicInfo(1,ip) = sum(ID.(PM).Topic==3); % Info convs
report.ID.(PM).avgChangeEEA(1,ip) = ...
    sum(cell2mat(ID.(PM).ChangeEEA))/sum(hh.N); % avg size of EEA change
report.ID.(PM).avgChangeEUEffort(1,ip) = ...
    sum(cell2mat(ID.(PM).change_eu_PE))/sum(hh.N); % avg size of EU Effort change
report.ID.(PM).LimitedByInfo(1,ip) = ...
    sum(cell2mat(ID.(PM).LimitedByInfo))/sum(hh.N); % avg share limited by info

for cl=1:hh.ClNumber 
    % report structs at cl level
    report.ID.(PM).cl.ChangeEEA(cl,ip) = ...
        sum(ID.(PM).ChangeEEA{cl})/hh.N(cl);
    report.ID.(PM).cl.ChangeEUEffort(cl,ip) = ...
        sum(ID.(PM).change_eu_PE{cl})/hh.N(cl);
    report.ID.(PM).cl.LimitedByInfo(cl,ip) = ...
        sum(ID.(PM).LimitedByInfo{cl})/hh.N(cl);

    % report structs at hh (struct) level
    report.ID.(PM).hh.Mates{cl,ip} = ID.(PM).Mates{cl,1};
    report.ID.(PM).hh.ChangeEEA{cl,ip} = ID.(PM).ChangeEEA{cl,1}; 
    report.ID.(PM).hh.ChangeEUEffort{cl,ip} = ID.(PM).change_eu_PE{cl,1};
    report.ID.(PM).hh.ChangeIndicator{cl,ip} = ID.(PM).ChangeIndicator{cl,1};
    report.ID.(PM).hh.SumChangeInd{cl,ip} = ID.(PM).SumChangeInd{cl,1};
    report.ID.(PM).hh.LimitedByInfo{cl,ip} = ID.(PM).LimitedByInfo{cl,1};
    report.ID.(PM).hh.LimitedByInfo_PE{cl,ip} = ID.(PM).LimitedByInfo_PE{cl,1};
    
end

% report structs at conversation level
report.ID.(PM).conv.Byhh{1,ip} = ID.(PM).ConversationByHH;
report.ID.(PM).conv.Sequence{1,ip} =ID.(PM).ConversationSeq;
report.ID.(PM).conv.Topic{1,ip} =ID.(PM).Topic;
report.ID.(PM).conv.EEA_Influencer{1,ip} =ID.(PM).EEA_Influencer;
report.ID.(PM).conv.Direction{1,ip} =ID.(PM).Direction;
report.ID.(PM).conv.StrongLink{1,ip} =ID.(PM).StrongLink;
report.ID.(PM).conv.SLR{1,ip} =ID.(PM).StrongLinkRelevant;

% save composition and setup on first call
if ~isfield(report.ID.(PM),'options')
    report.ID.(PM).options = options.ID.(PM); 
end

end