function ID_InstPlot(AC,hh,report,SimName,ip)
%ID_PLOT uses hh and report structures to plot figures on EA
%%%%%%%%%
% Input: hh and report structures, ip counter
%%%%%%%%%
% Returns: Figures, saved in results folder

% When not run inside Simulation.m run the following 2 lines
% ip=maxiter+1
% report = SimReport.BL

% get colormap
rgb(1,:)= [0,0,0];
rgb(2,:)= HInt2RGB(1,100); % red, darkest
rgb(3,:)= HInt2RGB(7,82); % cyan, less dark
rgb(4,:)= HInt2RGB(3,64); % green, less dark
rgb(5,:)= HInt2RGB(9,46); % magenta, less dark
rgb(6,:)= HInt2RGB(2,28); % orange, less dark
rgb(7,:)= HInt2RGB(7,10); % blue cyan, lightest

s = report.ID.Inst.(AC); %struct containing data

%% Report effect strength for first Campaign Period
FirstP = report.ID.Inst.(AC).setup.CampaignPeriod(1); 
    
c = categorical({'Avg','Cl1','Cl2','Cl3','Cl4','Cl5'});
% data: stack by row (i.e., 1st row: avg, 2nd row: Cl1,...
dat = NaN(1+hh.ClNumber,5); % 6=avg+5cl, 5= weak,PartlySt,Stong,PartlyFS,FullStrength
dat(1,1) = 1-s.NotWeak(FirstP);
dat(1,2) = s.PartlySt(FirstP);
dat(1,3) = s.Strong(FirstP);
dat(1,4) = s.PartlyFS(FirstP);
dat(1,5) = s.FullStrength(FirstP);
for clu = 1:hh.ClNumber
    dat(1+clu,1) = 1-s.Cl.NotWeak(clu,FirstP);
    dat(1+clu,2) = s.Cl.PartlySt(clu,FirstP);
    dat(1+clu,3) = s.Cl.Strong(clu,FirstP);
    dat(1+clu,4) = s.Cl.PartlyFS(clu,FirstP);
    dat(1+clu,5) = s.Cl.FullStrength(clu,FirstP);
end

figure
bar(c,dat,'stacked')
ACtitle = strrep(AC,'_',' ');
title([ACtitle,': Effect Strength']);
leg = legend({'Weak','Partly Strong','Strong','Partly FS','Full Strength'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03]; 
%[left bottom width height] lb: distance from lower left corner, wh: dimensions
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
name=[SimName,'_IDInst_',AC,'_EffectStrength'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');

%% Report avg and cluster-specific change of target-variable
figure;
hold on;
plot([NaN,s.update(2:ip)], 'Marker','x','MarkerEdgeColor',rgb(1,:),'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot([NaN,s.Cl.update(cl,2:ip)],'Marker','x','MarkerEdgeColor',rgb(cl+1,:), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
% Add effect size
Camp = report.ID.Inst.(AC).setup.CampaignPeriod;
for cp = 1:numel(Camp)
    try
        line([Camp(cp) Camp(cp)],[s.update(Camp(cp)) s.update(Camp(cp))-s.change(Camp(cp))],...
            'Color',[rgb(1,:) .65],'LineWidth',2);
        for cl=1:hh.ClNumber
            line([Camp(cp) Camp(cp)],...
                [s.Cl.update(cl,Camp(cp)) s.Cl.update(cl,Camp(cp))-s.Cl.change(cl,Camp(cp))],...
                'Color',[rgb(1+cl,:) .65],'LineWidth',1.7);
        end
    catch
        warning('Error in plotting effect of ID.Inst: At least some campaign periods > maxiter+1. Please check.')
    end
end

title([ACtitle,': Effect on target']);
xlabel('Time')
ylabel(report.ID.Inst.(AC).setup.AxisLabel)
legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',8 ...
    );
hold off;

name=[SimName,'_IDInst_',AC,'_EffectTarget'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');

end