function report = ID_InstReport(hh,ID,options,report,ip,maxiter)
%ID_InstReport Save ID of institutions and implied changes in report struct
%%%%%%%%%
% Input
% hh, ID, options structures
% ip: iteration period to store period-specific info
%%%%%%%%%
% Returns: Report structure, with options field

% save composition and setup on first call
if ip==2
    report.ID.Inst.Channels = options.ID.Inst.Channels;
    
    for j = 1:numel(options.ID.Inst.Channels(:,1))
        AC = strrep(options.ID.Inst.Channels(j,:),' ',''); % Active channel
        
        report.ID.Inst.(AC).setup = options.ID.Inst.(AC); 

        report.ID.Inst.(AC).FullStrength = NaN(1,maxiter+1); 
        report.ID.Inst.(AC).PartlyFS = NaN(1,maxiter+1); 
        report.ID.Inst.(AC).Strong = NaN(1,maxiter+1); 
        report.ID.Inst.(AC).PartlySt = NaN(1,maxiter+1); 
        report.ID.Inst.(AC).NotWeak = NaN(1,maxiter+1); 
        report.ID.Inst.(AC).EffectStrength = NaN(1,maxiter+1);
        report.ID.Inst.(AC).change = NaN(1,maxiter+1); 
        report.ID.Inst.(AC).update = NaN(1,maxiter+1); 

        report.ID.Inst.(AC).Cl.FullStrength = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.PartlyFS = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.Strong = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.PartlySt = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.NotWeak = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.EffectStrength = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.change = NaN(hh.ClNumber,maxiter+1);
        report.ID.Inst.(AC).Cl.update = NaN(hh.ClNumber,maxiter+1);
    end
    
end

N = sum(hh.N);
for j = 1:numel(options.ID.Inst.Channels(:,1))
    AC = strrep(options.ID.Inst.Channels(j,:),' ',''); % Active channel

    if ismember(ip,options.ID.Inst.(AC).CampaignPeriod)
        % descriptive statistics structs
        report.ID.Inst.(AC).FullStrength(1,ip) = sum(ID.Inst.(AC).FullStrength)/N;
        report.ID.Inst.(AC).PartlyFS(1,ip) = sum(ID.Inst.(AC).PartlyFS)/N;
        report.ID.Inst.(AC).Strong(1,ip) = sum(ID.Inst.(AC).Strong)/N;
        report.ID.Inst.(AC).PartlySt(1,ip) = sum(ID.Inst.(AC).PartlySt)/N;
        report.ID.Inst.(AC).NotWeak(1,ip) = sum(ID.Inst.(AC).NotWeak)/N;
        report.ID.Inst.(AC).EffectStrength(1,ip) = sum(ID.Inst.(AC).EffectStrength)/N;
        report.ID.Inst.(AC).change(1,ip) = sum(ID.Inst.(AC).change)/N;
        report.ID.Inst.(AC).update(1,ip) = sum(ID.Inst.(AC).update)/N;

        from = 1;
        for cl = 1:hh.ClNumber 
            till = sum(hh.N(1:cl));
            % report structs at cl level
            report.ID.Inst.(AC).Cl.FullStrength(cl,ip) = sum(ID.Inst.(AC).FullStrength(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.PartlyFS(cl,ip) = sum(ID.Inst.(AC).PartlyFS(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.Strong(cl,ip) = sum(ID.Inst.(AC).Strong(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.PartlySt(cl,ip) = sum(ID.Inst.(AC).PartlySt(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.NotWeak(cl,ip) = sum(ID.Inst.(AC).NotWeak(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.EffectStrength(cl,ip) = sum(ID.Inst.(AC).EffectStrength(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.change(cl,ip) = sum(ID.Inst.(AC).change(from:till))/hh.N(cl);
            report.ID.Inst.(AC).Cl.update(cl,ip) = sum(ID.Inst.(AC).update(from:till))/hh.N(cl);
            from = till + 1;
        end

        % report structs at hh level
        report.ID.Inst.(AC).hh.FullStrength{ip} = ID.Inst.(AC).FullStrength;
        report.ID.Inst.(AC).hh.PartlyFS{ip} = ID.Inst.(AC).PartlyFS;
        report.ID.Inst.(AC).hh.Strong{ip} = ID.Inst.(AC).Strong;
        report.ID.Inst.(AC).hh.PartlySt{ip} = ID.Inst.(AC).PartlySt;
        report.ID.Inst.(AC).hh.NotWeak{ip} = ID.Inst.(AC).NotWeak;
        report.ID.Inst.(AC).hh.EffectStrength{ip} = ID.Inst.(AC).EffectStrength;
        report.ID.Inst.(AC).hh.target{ip} = ID.Inst.(AC).target;
        report.ID.Inst.(AC).hh.change{ip} = ID.Inst.(AC).change;
        report.ID.Inst.(AC).hh.update{ip} = ID.Inst.(AC).update;
    end

end

end