function ID_Plot(PM,hh,report,SimName,ip)
%ID_PLOT uses hh and report structures to plot figures on EA
%%%%%%%%%
% Input: hh and report structures, ip counter
%%%%%%%%%
% Returns: Figures, saved in results folder

% get colormap
rgb(1,:)= [0,0,0];
rgb(2,:)= HInt2RGB(1,100); % red, darkest
rgb(3,:)= HInt2RGB(7,82); % cyan, less dark
rgb(4,:)= HInt2RGB(3,64); % green, less dark
rgb(5,:)= HInt2RGB(9,46); % magenta, less dark
rgb(6,:)= HInt2RGB(2,28); % orange, less dark
rgb(7,:)= HInt2RGB(7,10); % blue cyan, lightest

%% At the conversation level
figure;
% General plot
subplot(2,2,1);
hold on;
plot([NaN,report.ID.(PM).Num.Total(2:ip)], 'LineWidth',2, 'Color',rgb(1,:));
plot([NaN,report.ID.(PM).Num.TopicEA(2:ip)], 'LineWidth',2, 'Color',rgb(2,:));
plot([NaN,report.ID.(PM).Num.TopicEU(2:ip) + report.ID.(PM).Num.TopicEA(2:ip)],...
    'LineWidth',2, 'Color',rgb(3,:));

THEA = .5*report.ID.(PM).Num.TopicEA(2); % text heigth for EA
THEU = .5*report.ID.(PM).Num.TopicEU(2) + report.ID.(PM).Num.TopicEA(2); % for EU
THRT = .5*(report.ID.(PM).Num.Total(2) + report.ID.(PM).Num.TopicEA(2) + report.ID.(PM).Num.TopicEU(2));
text(2.1,THEA,'Topic EA','Color',rgb(2,:))
text(2.1,THEU,'Topic EU','Color',rgb(3,:))
text(2.1,THRT,'Other topic','Color',rgb(1,:))

title(sprintf('ID %s: # of conversations',PM));
xlabel('Time')
leg = legend({'Total','Topic EA','Topic EU'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03]; 
%[left bottom width height] lb: distance from lower left corner, wh: dimensions
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off;

subplot(2,2,2);
hold on;
plot([NaN,report.ID.(PM).Num.Total(2:ip)./report.ID.(PM).Num.Total(2).*100],...
    'LineWidth',2, 'Color',rgb(1,:));
plot([NaN,report.ID.(PM).Num.TopicEA(2:ip)./report.ID.(PM).Num.TopicEA(2).*100],...
    'LineWidth',2, 'Color',rgb(2,:));
plot([NaN,report.ID.(PM).Num.TopicEU(2:ip)./report.ID.(PM).Num.TopicEU(2).*100],...
    'LineWidth',2, 'Color',rgb(3,:));
title('# of conversations: Relative change')
ylabel('%')
xlabel('Time')
hold off;


subplot(2,2,3);
hold on;
plot([NaN,report.ID.(PM).avgChangeEEA(2:ip).*100], 'LineWidth',2, 'Color',rgb(2,:));
title('Avg change of EEA PreferredShare');
xlabel('Time')
ylabel('% pts / hh')
hold off;

subplot(2,2,4);
hold on;
plot([NaN,report.ID.(PM).avgChangeEUEffort(2:ip)], 'LineWidth',2, 'Color',rgb(3,:));
title('Avg change in EU Effort');
xlabel('Time')
ylabel('kWh / hh')
hold off;

name=[SimName,'_ID_',PM,'_Descriptives'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');

%% At the household level
figure;
% Cluster-specific plot
subplot(2,1,1);
hold on;
plot([NaN,report.ID.(PM).avgChangeEEA(2:ip).*100], 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot([NaN,report.ID.(PM).cl.ChangeEEA(cl,2:ip).*100], 'LineWidth',1, 'Color',rgb(cl+1,:));
end
title(sprintf('ID %s: Change of EEA PreferredShare by cluster',PM));
xlabel('Time')
ylabel('% pts / hh')
% legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
%     ,'Location','southoutside'...
%     ,'Orientation','horizontal'...
%     ,'FontSize',8 ...
%     );
hold off;

subplot(2,1,2);
hold on;
plot([NaN,report.ID.(PM).avgChangeEUEffort(2:ip)], 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot([NaN,report.ID.(PM).cl.ChangeEUEffort(cl,2:ip)], 'LineWidth',1, 'Color',rgb(cl+1,:));
end

title(sprintf('ID %s: Change in EU Effort by cluster',PM));
xlabel('Time')
ylabel('kWh / hh')

leg=legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03]; 
%[left bottom width height] lb: distance from lower left corner, wh: dimensions
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off;

name=[SimName,'_ID_',PM,'_byCl'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');


% Limited by Information
if max(report.ID.(PM).LimitedByInfo)>0
    
    figure;
    hold on;
    plot([NaN,report.ID.(PM).LimitedByInfo(2:ip).*100], 'LineWidth',2, 'Color',rgb(1,:));
    for cl=1:hh.ClNumber
        plot([NaN,report.ID.(PM).cl.LimitedByInfo(cl,2:ip).*100], 'LineWidth',1, 'Color',rgb(cl+1,:));
    end
    title(sprintf('ID %s: Share of hhs limited by information, by cluster',PM));
    xlabel('Time')
    ylabel('%')
    legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
        ,'Location','southoutside'...
        ,'Orientation','horizontal'...
        ,'FontSize',8 ...
        );
    hold off;

    name=[SimName,'_ID_',PM,'_LimitedByInfo'];
    print([pwd '\results\simulation\' name],'-dpdf','-bestfit');
end

end