function options = ID_options(options,NW,PickMates,NumMates,Ties,TopicScore)
%%%%%%%%%
    if ~ischar(PickMates)
        error('PickMates not in character format. Must be random, byCl, or set to existing NW.');
    end
    
    options.ID.(PickMates).PickMates = PickMates;
    options.ID.(PickMates).byNW = 0;
    
    switch PickMates 
        case 'random'
            fprintf('\nID options for mates picked at random.\n');
        case 'byCl'
            fprintf('\nID options for mates picked within cluster.\n');
        otherwise
            if isfield(NW,PickMates) == 1
                options.ID.(PickMates).byNW = 1;
                fprintf('\nID options for mates picked within network %s.\n',...
                    options.ID.(PickMates).PickMates);
            else
                warning('PickMates = %s is not allowed. Must be random, byCl, or set to existing NW. The NW %s, however, does not exist.\nTherefore, options.ID.%s.PickMates set to random.'...
                    ,PickMates, PickMates, PickMates);
                options.ID.(PickMates).PickMates = 'random'; 
            end
    end
    
    if isfield(NumMates,'mean')
        options.ID.(PickMates).NumMates.mean = NumMates.mean; 
        fprintf('options.ID.%s.NumMates.mean = %.2f. ',...
            PickMates,options.ID.(PickMates).NumMates.mean);
        if isfield(NumMates,'se')
            options.ID.(PickMates).NumMates.se = NumMates.se; 
            fprintf('options.ID.%s.NumMates.se = %.2f.\n',...
                PickMates,options.ID.(PickMates).NumMates.se);
        else 
            options.ID.(PickMates).NumMates.se = 0;
            fprintf('options.ID.%s.NumMates.se not specified; set to 0.\n',...
                PickMates);
        end
    elseif isnumeric(NumMates) && NumMates > 0
        options.ID.(PickMates).NumMates.mean = round(NumMates);
        options.ID.(PickMates).NumMates.se = 0;
        fprintf('options.ID.%s.NumMates fixed at %.0f.\n',...
            PickMates,options.ID.(PickMates).NumMates.mean);
    else
        error('NumMates specified in invalid format. Must be struct with field mean (and potentially se) or a positive number.');
    end
    
    if options.ID.(PickMates).byNW == 1 && (~exist('Ties','var') || isempty(Ties))
        options.ID.(PickMates).Ties = 'equal';
        warning('ID: Ties not determined. options.ID.%s.Ties set to equal.\n',...
            PickMates);
    elseif options.ID.(PickMates).byNW == 1
        options.ID.(PickMates).Ties = Ties;
        switch Ties
            case 'equal'
                fprintf('ID: No strong/weak ties for primary and secondary networks. (options.ID.%s.Ties = equal).\n',...
                    PickMates);
            case 'strongweak'
                fprintf('ID: Ties to mates with strong/weak discrimination for primary and secondary networks. (options.ID.%s.Ties = strongweak).\n',...
                    PickMates);
            otherwise
                warning('Ties = %s is not allowed. Must be equal or strongweak. Set to equal.\n',...
                    Ties);
                options.ID.(PickMates).Ties = 'equal';
        end
    end
    
    if ~exist('TopicScore','var')
        TopicScore = struct;
    end
    if ~isfield(TopicScore,'other')
        TopicScore.other = 35;
        fprintf('ID: TopicScore.other did not exist; set to %.0f.\n',...
            TopicScore.other);
    end
    if ~isfield(TopicScore,'EU') % This is independent of modes.EU=active
        TopicScore.EU = 5;
        fprintf('ID: TopicScore.EU did not exist; set to %.0f.\n',...
            TopicScore.EU);
    end
    if ~isfield(TopicScore,'EA')
        TopicScore.EA = 5;
        fprintf('ID: TopicScore.EA did not exist; set to %.0f.\n',...
            TopicScore.EA);
    end
    if ~isfield(TopicScore,'Info')
        TopicScore.Info = 5;
        fprintf('ID: TopicScore.Info did not exist; set to %.0f.\n',...
            TopicScore.Info);
    end
    
    options.ID.(PickMates).TopicScore = TopicScore;


end
