function report = IT_Reporting(hh, report, ip, maxiter)
%IT_REPORTING Reporting of period-specific IT measures on the aggregate, 
% cluster and individual level.
%%%%%%%%%
% Input: hh structure, report structure, ip, and maxiter [opt]
%%%%%%%%%
% Returns: report structure


from = hh.IT.from; % load sources of IT from hh struct
N=sum(hh.N); 

switch ip
    case 1 % initial period
        disp('IT Reporting for initial setup.')
        % Use initial period to setup reporting structure
        for f = 1:length(from(:,1))
            source = strrep(from(f,:),' ','');

            % Aggregate IT reporting measures
            report.IT.Info.(source) = NaN(maxiter+1,1);
            report.IT.Trust.(source) = NaN(maxiter+1,1);

            % IT reporting measures by cluster
            report.Cl.IT.Info.(source) = NaN(maxiter+1,hh.ClNumber);
            report.Cl.IT.Trust.(source) = NaN(maxiter+1,hh.ClNumber);

            % Individual NI reporting measures
            report.hh.IT.Info.(source){hh.ClNumber,maxiter+1} = 0;
            report.hh.IT.Trust.(source){hh.ClNumber,maxiter+1} = 0;
            for period=1:maxiter+1 % do NOT use same index as for iteration
                for cluster=1:hh.ClNumber
                    report.hh.IT.Info.(source){cluster,period} = ...
                        NaN(hh.N(cluster),1);
                    report.hh.IT.Trust.(source){cluster,period} = ...
                        NaN(hh.N(cluster),1);
                end
            end
        end
end

% IT reporting
for f = 1:length(from(:,1))
    source = strrep(from(f,:),' ','');
    
    % ... aggregate
    report.IT.Info.(source)(ip) = sum(cell2mat(hh.IT.Info.(source)))/N;
    report.IT.Trust.(source)(ip) = sum(cell2mat(hh.IT.Trust.(source)))/N;

    for cl=1:hh.ClNumber 
        % ... cluster
        report.Cl.IT.Info.(source)(ip,cl) = ...
            sum(hh.IT.Info.(source){cl,1}(:)/hh.N(cl));
        report.Cl.IT.Trust.(source)(ip,cl) = ...
            sum(hh.IT.Trust.(source){cl,1}(:)/hh.N(cl));

        % ... individuum
        report.hh.IT.Info.(source){cl,ip} = hh.IT.Info.(source){cl,1};
        report.hh.IT.Trust.(source){cl,ip} = hh.IT.Trust.(source){cl,1};
    end

end