function Cl = ImpData2Cl_Nx2(Cl,ImpData,inputname,outputname,oul1,oul2,oul3,by)
%IMPDATA2CL_NX2 Feeds ImpData.(inputname).predict/se into Cluster structure
%%%%%%%%%
% Input:
% Cl structure, with required field: number 
% ImpData structure, with required fields: numdesc, numinj, numlit,
%   (inputname).predict/se.
% inputname char vector that contains (list of) input variable(s)
%   (ImpData.(inputname).predict/se has to exist).
% outlowerlevel determines outputname for inputname (equal length)
% oul1,oul2,oul3 gives Cl.(outupperlevel1).(...2).(...3).(outlowerlevel)...
%   if not required, set to 'none'.
% (optional) by = 'bycl' defines input from multiple files, i.e., Clnumber
%   files in ImpData, with cl = 1,...,Clnumber being the last character of 
%   ImpData.(inputname[num2str(cl)])...
%%%%%%%%%
% Output: 
% 4-dimensional matrix of form
%   Cl.[(oul1...3).](outputname).mean/se(desc,inj,lit,cl).

if numel(inputname(:,1))~=numel(outputname(:,1))
    error('inputname and outlowerlevel are not of equal length. \nInput names specified: %.0f, Output names specified: %.0f.\n'...
        ,numel(inputname(:,1)),numel(outputname(:,1)))
end

if ~exist('by','var')
    by = 'notset';
end

switch by
    case 'bycl' 
        % inputname specified as cluster-specific input with one file for
        % each cluster.
        Cl = ImpData2Cl_Nx2_bycl(Cl,ImpData,inputname,outputname,oul1,oul2,oul3);

    case 'notset'
        Cl = ImpData2Cl_Nx2_1file(Cl,ImpData,inputname,outputname,oul1,oul2,oul3);

    otherwise
        warning('by option in ImpData2Cl_Nx2 is activated but set to not allowed value: \nby = %s, but the only specified option is bycl. \nTreated as not activated.'...
            ,by)
        Cl = ImpData2Cl_Nx2_1file(Cl,ImpData,inputname,outputname,oul1,oul2,oul3);

end

end

