function [Input, ImpData] = Import_Data(Input,ImpData)
%IMPORT_DATA Function to translate text/ csv data files in Input and ImpData
% structures.
%%%%%%%%%
% Input: Input (InputStructure), and ImpData structures
%%%%%%%%%
% Returns/updates: Input, and ImpData structures


%% Import descriptive statistics data

%%%%%%%%%%%%%%%%%  EA  %%%%%%%%%%%%%%%%%%%%%%
% ----------- EA by cluster:
% Format for each line of text:
% column2:6 double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%*s%f%f%f%f%f%[^\n\r]';
% Open the text file.
fileID = fopen('EA_cl_2019.csv','r');
% Read columns of data according to the format.
dataArray = textscan(fileID, formatSpec, 'Delimiter', ',', 'HeaderLines' ,1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
% Close the text file.
fclose(fileID);
% Allocate imported array to column variable names
Input.number = length(dataArray{:,1}); % This identifies # of clusters
ImpData.ClNumber = Input.number; % Copy # of clusters to ImpData-struct
Input.EA.N = dataArray{:, 1};
Input.EA.Stock.Mean = dataArray{:, 2};
Input.EA.Stock.sd = dataArray{:, 3};
Input.EA.share = Input.EA.N./sum(Input.EA.N); % Relative size of cluster


% ----------- EA by cluster and category:
% Format for each line of text:
% column3:7 double (%f)
% For more information, see the TEXTSCAN documentation.
formatSpec = '%*s%*s%f%f%f%f%f%[^\n\r]';
% Open the text file.
fileID = fopen('EA_cl_cat_2019.csv','r');
% Read columns of data according to the format.
dataArray = textscan(fileID, formatSpec, 'Delimiter', ',', 'HeaderLines' ,1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
% Close the text file.
fclose(fileID);
% Allocate imported array to column variable names
if isfield(Input,'number') == 1 % number of clusters already defined
    if mod(length(dataArray{:,1}),Input.number)~=0
        error('Error in Import_EA_cl_cat.m. Check number of clusters imported from Stata. \nCurrently it is set to Input.number = %.0f, but length(dataArray{:,1}) = %.0f, which is not a multiple of Input.number.'...
            ,Input.number,length(dataArray{:,1}));
    end
else
    Input.number=5;
    warning('In Import_EA_cl_cat.m, Input.number was not set. Now set to %.0f.\n',Input.number)
    if mod(length(dataArray{:,1}),Input.number)~=0
        error('Error in Import_EA_cl_cat.m. \nCheck number of clusters. Input.number = %.0f is incompatible as length(dataArray{:,1}) = %.0f is not a multiple of Input.number.'...
            ,Input.number,length(dataArray{:,1}));
    end
end
Input.Cat.number = length(dataArray{:,1})/Input.number;
Input.Cat.EA.N = NaN(Input.Cat.number,Input.number);
Input.Cat.EA.Stock.Mean = Input.Cat.EA.N;
Input.Cat.EA.Stock.sd = Input.Cat.EA.N;
Input.Cat.CondProb = Input.Cat.EA.N;

for cl=1:Input.number
    for cat=1:Input.Cat.number
        Input.Cat.EA.N(cat,cl)          = dataArray{:, 1}((cl-1)*Input.Cat.number+cat);
        Input.Cat.EA.Stock.Mean(cat,cl) = dataArray{:, 2}((cl-1)*Input.Cat.number+cat);
        Input.Cat.EA.Stock.sd(cat,cl)   = dataArray{:, 3}((cl-1)*Input.Cat.number+cat);
    end
end

Input.Cat.EA.share = Input.Cat.EA.N./sum(Input.Cat.EA.N); % Relative size of categories

for cl=1:Input.number
    for cat=1:Input.Cat.number
        % Conditional probabilities: Probability of belonging to CatX,  
        % conditional on not belonging to Cat1:Cat(X-1)
        Input.Cat.EA.CondProb(cat,cl)=Input.Cat.EA.share(cat,cl) ...
            /sum(Input.Cat.EA.share(cat:end,cl));
    end
end

%%%%%%%%%%%%%%%%%  Cantons  %%%%%%%%%%%%%%%%%%%%%%
% define if canton data important on cluster level (=1) or by cluster and
% category (=2)
Input.KtImport = 2;

switch Input.KtImport
    case 1 % import on cluster level
        % canton names
        formatSpec = '%*s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%*[^\n\r]';
        % Open the text file.
        fileID = fopen('elec_cl_kt.txt','r');
        % Read columns of data according to the format.
        % dataArray = textscan(fileID, formatSpec, 'Delimiter', '\t', 'HeaderLines' ,3, 'ReturnOnError', false, 'EndOfLine', '\r\n');
        delimiter ='\t';
        startRow = 2;
        endRow = 2;
        dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
        % Close the text file.
        fclose(fileID);
        Input.ClKtName = dataArray;

        % number of HHs by canton
        formatSpec = '%*s%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%*[^\n\r]';
        % Open the text file.
        fileID = fopen('elec_cl_kt.txt','r'); % based on EA SHEDS data
        % Read columns of data according to the format.     
        delimiter ='\t';
        startRow = 4;
        endRow = 8;
        dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
        % Close the text file.
        fclose(fileID);

        % Allocate imported array to column variable names
        Input.ClKtNumber = length(dataArray{:,1}); % This identifies # of clusters
        Input.KtNumber = length(dataArray); % This identifies # of clusters
        ImpData.ClKtNumber = Input.ClKtNumber; % Copy # of clusters to ImpData-struct
        ImpData.KtNumber = Input.KtNumber; % Copy # of clusters to ImpData-struct
        Input.NClKt = NaN(Input.KtNumber,Input.ClKtNumber);
        Input.ClKtshare = Input.NClKt;
        Input.ClKtCondProb = Input.NClKt;

        for cl=1:Input.ClKtNumber
            for kt=1:ImpData.KtNumber
                Input.NClKt(kt,cl) = dataArray{:, kt}(cl);
            end
        end
        Input.ClKtshare = Input.NClKt./sum(Input.NClKt); % Relative size

        for cl=1:Input.number
            for kt=1:ImpData.KtNumber
                % Conditional probabilities: Probability of belonging to CatX,  
                % conditional on not belonging to Cat1:Cat(X-1)
                Input.ClKtCondProb(kt,cl)=Input.ClKtshare(kt,cl) ...
                    /sum(Input.ClKtshare(kt:end,cl));
            end
        end  
        
    case 2 % import on cluster and category level
        % canton names
        formatSpec = '%*s%*s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%*[^\n\r]';
        % Open the text file.
        fileID = fopen('elec_cl_cat_kt2.txt','r');
        % Read columns of data according to the format.       
        delimiter ='\t';
        startRow = 1;
        endRow = 1;
        dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
        % Close the text file.
        fclose(fileID);
        Input.ClKtName = dataArray;

        % number of HHs by canton
        formatSpec = '%*s%*s%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%f%*[^\n\r]';
        % Open the text file.
        fileID = fopen('elec_cl_cat_kt2.txt','r'); % based on EA SHEDS data
        % Read columns of data according to the format.
        % dataArray = textscan(fileID, formatSpec, 'Delimiter', '\t', 'HeaderLines' ,3, 'ReturnOnError', false, 'EndOfLine', '\r\n');
        delimiter ='\t';
        startRow = 2;
        endRow = 41;
        dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
        % Close the text file.
        fclose(fileID);

        % Allocate imported array to column variable names
        Input.ClKtNumber = length(dataArray{:,1})/8; % This identifies # of clusters
        Input.CatKtNumber = length(dataArray{:,1})/Input.ClKtNumber;
        Input.KtNumber = length(dataArray); % This identifies # of clusters
        ImpData.ClKtNumber = Input.ClKtNumber; % Copy # of clusters to ImpData-struct
        ImpData.KtNumber = Input.KtNumber; % Copy # of clusters to ImpData-struct
        Input.NClKt = NaN(Input.ClKtNumber,Input.CatKtNumber,Input.KtNumber);
        Input.ClKtshare = Input.NClKt;
        Input.ClCatKtCondProb = Input.NClKt;


        for cl=1:Input.ClKtNumber
            for cat=1:Input.CatKtNumber
                for kt=1:ImpData.KtNumber
                    Input.NClKt(cl,cat,kt) = dataArray{:, kt}((cl-1)*Input.Cat.number+cat);
                end
            end
        end
        
        for cl=1:Input.number 
            for cat=1:Input.CatKtNumber
                for kt=1:ImpData.KtNumber
                   % Conditional probabilities: Probability of belonging to CatX,  
                    % conditional on not belonging to Cat1:Cat(X-1)
                    Input.ClKtshare(cl,cat,kt)=Input.NClKt(cl,cat,kt) ...
                        /sum(Input.NClKt(cl,cat,1:end));
                end
            end
        end
        
        for cl=1:Input.number 
            for cat=1:Input.CatKtNumber
                for kt=1:ImpData.KtNumber
                   % Conditional probabilities: Probability of belonging to CatX,  
                    % conditional on not belonging to Cat1:Cat(X-1)
                    Input.ClCatKtCondProb(cl,cat,kt)=Input.ClKtshare(cl,cat,kt) ...
                        /sum(Input.ClKtshare(cl,cat,kt:end));
                end
            end
        end
end

%%%%%%%%%%%  Information and trust (only by cluster)  %%%%%%%%%%%%%%%

from = char(...
    'fam', ... from family, friends or collegues
    'neighbor', ... from neighbors
    'SFOE', ... from the Swiss federal office of energy
    'utility' ... from the local energy supply utility
    );

for f = 1:length(from(:,1))
    fromf = strrep(from(f,:),' ','');

    InfoName = ['info_',fromf,'_cl_2019']; % cl*3 Table, with 
    % column1(2)[3]: info = -2(0)[1]
    ImpData.(InfoName) = ImportInfo([InfoName,'.csv']);
    
    TrustName = ['trust_',fromf,'_cl_2019']; % cl*5 Table, with 
    % column1...5: trust = 1 (not at all) ... 5 (very strongly)
    ImpData.(TrustName) = ImportTrust([TrustName,'.csv']);
    
    Input.IT.Info.Share.(fromf) = ImpData.(InfoName)(:,3)./...
        sum(ImpData.(InfoName)(:,2:3),2); %share who took info from source
    
    SumTrust = sum(ImpData.(TrustName),2);
    for tru = 1:length(ImpData.(TrustName)(1,:))
        Input.IT.Trust.Share.(fromf)(:,tru) = ImpData.(TrustName)(:,tru)./...
            SumTrust; % cluster in rows, trust score in columns
        Input.IT.Trust.CondProb.(fromf)(:,tru) = ...
            ImpData.(TrustName)(:,tru)./...
            sum(ImpData.(TrustName)(:,tru:end),2);
    end
end
    
Input.IT.from = from; % save from in cluster struct


%%%%%%%%%%%%%%%%%  Effort  %%%%%%%%%%%%%%%%%%%%%%
% Effort of HHs to reduce their electricity usage
EffortLevelData = 'EffortElec_cl_2019'; % cl*5 Table, with 
% column1...5: EffortLevel = 1 (Very unlikely) ... 5 (Very likely)
% Same structure as Trust, therefore use ImportTrust function to import
% data
ImpData.(EffortLevelData) = ImportTrust([EffortLevelData,'.txt']);
    
SumEffortLevel = sum(ImpData.(EffortLevelData),2);
for eff = 1:length(ImpData.(EffortLevelData)(1,:))
    Input.EU.EffortLevel.Share(:,eff) = ...
        ImpData.(EffortLevelData)(:,eff)./...
        SumEffortLevel; % cluster in rows, EffortLevel score in columns
    
    Input.EU.EffortLevel.CondProb(:,eff) = ...
        ImpData.(EffortLevelData)(:,eff)./...
        sum(ImpData.(EffortLevelData)(:,eff:end),2);
end

EffortLevelPrData = 'Elec_Effort_OLS_lit_inj_desc_cl_2019';
ImpData.(EffortLevelPrData) = importNx1([EffortLevelPrData,'.csv']);

Input.EU.EffortLevel.predict = zeros(ImpData.numlit,ImpData.numinj,ImpData.numdesc,Input.number);

for cl=1:Input.number
    for lit=1:ImpData.numlit
        for inj=1:ImpData.numinj
            for desc=1:ImpData.numdesc
                Input.EU.EffortLevel.predict(lit,inj,desc,cl) =...
                    ImpData.Elec_Effort_OLS_lit_inj_desc_cl_2019(...
                    lit*ImpData.numinj*ImpData.numdesc*Input.number...
                    + ImpData.numdesc*Input.number*(inj-ImpData.numinj)...
                    + Input.number * (desc - ImpData.numdesc)...
                    +(cl - Input.number));
            end
        end
    end
end

%% Import estimated data


%%%%%%%%%%%%%%  Nx1 arrays (distribution of NI by cl and by cl,cat)
% name of variable indicates order (see first two)
importvar=char(...
     'marg_desc_cl'...      25x1 --> 5cl*5desc      desc = [1,2,3,4,5]      by desc,cl      (1:5 desc=1, 6:10 desc=2, ...)
    ,'marg_desc_cl_cat'... 200x1 --> 5cl*8cat*5desc                         by desc,cl,cat  (1:40 desc=1, 1:8 cl=1, ...)
    ,'marg_inj_cl'...       45x1 --> 5cl*9inj       inj = [1,1.5,2,...,5]
    ,'marg_inj_cl_cat'...  360x1 --> 5cl*8cat*9inj
    ,'marg_lit_cl'...       55x1 --> 5cl*11lit      lit = [0,1,2,...,10]    lit=11 not observed, but possible (56:60=0)
    ,'marg_lit_cl_cat'...  440x1 --> 5cl*8cat*11lit
    );

for imp=1:length(importvar(:,1))
    name=strrep(importvar(imp,:),' ','');
    ImpData.(name) = importNx1([name,'.csv']);

    % Minimal plausibility check of imported data
    if mod(length(ImpData.(name)(:,1)),Input.number)~=0 ...
            && length(ImpData.(name).predict(:,1)) > 1
        error('Error when importing %s: It is incompatible with Input.number = %.0f. \nThe reason is that length(ImpData.%s(:,1)) = %.0f is not a multiple of Input.number.'...
            ,name,Input.number,name,length(ImpData.(name)(:,1)));
    end
end
% Adjust literacy scale to 11 (theoretical maximum, but not observed)
if numel(ImpData.marg_lit_cl)==ImpData.ClNumber*(ImpData.numlit-1)
    warning('Literacy==11 not observed and therefore not estimated by margins (in Stata); missing zeros added manually.')
    ImpData.marg_lit_cl(56:60) = 0;
    ImpData.marg_lit_cl_cat(441:480) = 0;
elseif numel(ImpData.marg_lit_cl)<ImpData.ClNumber*(ImpData.numlit-1)
    error('Literacy observed for less than anticipated values (ImpData.numlit and ImpData.numlit-1). Check if correct in Stata and solve manually.')
end


%%%%%%%%%%%%%% Nx2 matrices (distribution of EEA, EEA_Share, LEA, EU)
% column1 = predicted number of events, column2 = SE
importvar=char(...
    ... EEA 
     'EEA_marg_cl1'...       
    ,'EEA_marg_cl2'...       
    ,'EEA_marg_cl3'...       
    ,'EEA_marg_cl4'...       
    ,'EEA_marg_cl5'...       
    ... EEA_Share
    ,'EEA_share_cl'...      
    ... Elec_Use 
    ,'Elec_Use_marg_cl1'... 
    ,'Elec_Use_marg_cl2'... e.g., 1x2   --> constant for cl = 2
    ,'Elec_Use_marg_cl3'... 
    ,'Elec_Use_marg_cl4'... e.g., 12x2  --> by lit for cl = 4
    ,'Elec_Use_marg_cl5'... 
    );
for imp=1:length(importvar(:,1))
    name=strrep(importvar(imp,:),' ','');
    [ImpData.(name).predict, ImpData.(name).se] = ...
        importNx2([name,'.csv']);

    ImpData.numdesc = 9;
    
    % Minimal plausibility check of imported data
    if mod(length(ImpData.(name).predict(:,1)),Input.number)~=0 ...
            && sum(length(ImpData.(name).predict(:,1)) == ...
                [1 ImpData.numdesc ImpData.numinj ImpData.numlit ...
                ImpData.numdesc*ImpData.numinj ...
                ImpData.numdesc*ImpData.numlit ...
                ImpData.numinj*ImpData.numlit ...
                ImpData.numdesc*ImpData.numinj*ImpData.numlit ...
                ])==0
        error('Error when importing %s: It is incompatible with Input.number = %.0f. \nThe reason is that length(ImpData.%s.predict(:,1)) = %.0f is not a linear combination of Input.number or the length of NI variables.'...
            ,name,Input.number,name,length(ImpData.(name).predict(:,1)));
    end
end

%% Format imported data (reshape array to matrix)
% (Transform ImpData structs to Input structs)
% ImpData must be ordered by desc, inj, lit. This means first come all
% desc=1, inj=1, lit=0:11, then desc=1, inj=1.5, lit=0:11, ..., until
% desc=5, inj=5, lit=11

%%%%%%%%%%%%%% Nx1 arrays

ImpData.numdesc = 5;

Input.NI.desc.share=zeros(ImpData.numdesc,Input.number);
Input.NI.desc.CondProb=Input.NI.desc.share;
Input.NI.inj.share=zeros(ImpData.numinj,Input.number);
Input.NI.inj.CondProb=Input.NI.inj.share;
Input.NI.lit.share=zeros(ImpData.numlit,Input.number);
Input.NI.lit.CondProb=Input.NI.lit.share;

Input.Cat.NI.desc.share=zeros(ImpData.numdesc,Input.Cat.number,Input.number);
Input.Cat.NI.desc.CondProb=Input.Cat.NI.desc.share;
Input.Cat.NI.inj.share=zeros(ImpData.numinj,Input.Cat.number,Input.number);
Input.Cat.NI.inj.CondProb=Input.Cat.NI.inj.share;
Input.Cat.NI.lit.share=zeros(ImpData.numlit,Input.Cat.number,Input.number);
Input.Cat.NI.lit.CondProb=Input.Cat.NI.lit.share;

for cl=1:Input.number
    % at cluster level
    for desc=1:ImpData.numdesc
        Input.NI.desc.share(desc,cl) = ImpData.marg_desc_cl(...
            (desc-1)*Input.number + cl ...
            );
    end
    for inj=1:ImpData.numinj
        Input.NI.inj.share(inj,cl) = ImpData.marg_inj_cl(...
            (inj-1)*Input.number + cl ...
            );
    end
    for lit=1:ImpData.numlit
        Input.NI.lit.share(lit,cl) = ImpData.marg_lit_cl(...
            (lit-1)*Input.number + cl ...
            );
    end

    % at cluster and category level
    for cat=1:Input.Cat.number
        for desc=1:ImpData.numdesc
            Input.Cat.NI.desc.share(desc,cat,cl) = ImpData.marg_desc_cl_cat(...
                desc*Input.number*Input.Cat.number + Input.Cat.number*(cl-Input.number)+ (cat-Input.Cat.number) ...
                );
        end
        for inj=1:ImpData.numinj
            Input.Cat.NI.inj.share(inj,cat,cl) = ImpData.marg_inj_cl_cat(...
                inj*Input.number*Input.Cat.number + Input.Cat.number*(cl-Input.number)+ (cat-Input.Cat.number) ...
                );
        end
        for lit=1:ImpData.numlit
            Input.Cat.NI.lit.share(lit,cat,cl) = ImpData.marg_lit_cl_cat(...
                lit*Input.number*Input.Cat.number + Input.Cat.number*(cl-Input.number)+ (cat-Input.Cat.number) ...
                );
        end
    end
end

% check if sum(Input.NI.lit.share(:,:)) is a vector of 1s.
% check if sum(Input.Cat.NI.desc.share(:,:,:)) is a matrix of 1s.

% calculate conditional probabilities 
% (probability of belonging to X, if not belonging to X-1)
for cl=1:Input.number
    for desc=1:ImpData.numdesc
        Input.NI.desc.CondProb(desc,cl) = Input.NI.desc.share(desc,cl) ...
            / sum(Input.NI.desc.share(desc:end,cl));
    end
    for inj=1:ImpData.numinj
        Input.NI.inj.CondProb(inj,cl) = Input.NI.inj.share(inj,cl) ...
			/ sum(Input.NI.inj.share(inj:end,cl));
    end
    for lit=1:ImpData.numlit
        Input.NI.lit.CondProb(lit,cl) = Input.NI.lit.share(lit,cl) ...
			/ sum(Input.NI.lit.share(lit:end,cl));
    end

    for cat=1:Input.Cat.number
        for desc=1:ImpData.numdesc
            Input.Cat.NI.desc.CondProb(desc,cat,cl) = Input.Cat.NI.desc.share(desc,cat,cl) ...
                / sum(Input.Cat.NI.desc.share(desc:end,cat,cl));
        end
        for inj=1:ImpData.numinj
            Input.Cat.NI.inj.CondProb(inj,cat,cl) = Input.Cat.NI.inj.share(inj,cat,cl) ...
				/ sum(Input.Cat.NI.inj.share(inj:end,cat,cl));
        end
        for lit=1:ImpData.numlit
            Input.Cat.NI.lit.CondProb(lit,cat,cl) = Input.Cat.NI.lit.share(lit,cat,cl) ...
				/ sum(Input.Cat.NI.lit.share(lit:end,cat,cl));
        end
    end
end


Input.NI.lit.CondProb(isnan(Input.NI.lit.CondProb)) = 0; 
Input.Cat.NI.lit.CondProb(isnan(Input.Cat.NI.lit.CondProb)) = 0; 


%%%%%%%%%%%%%% Nx2 arrays

%%%%%%% Electric appliances

varname = char(... %ImpData.(varname) must exist
    'EEA_marg_cl'...
    ); 
outputname = char(...
    'EEA'...
    );
Input = ImpData2Cl_Nx2(Input,ImpData,varname,outputname,'EA','large','none','bycl'); 

varname = char(... %ImpData.(varname) must exist
    'EEA_share_cl'...
    ); 
outputname = char(...
    'EEA_Share'...
    );
Input = ImpData2Cl_Nx2(Input,ImpData,varname,outputname,'EA','large','none');     

%%%%%%% Electricity use
% Oct '19: Marginal output from stata at(ea_total=(0(1)8)) over(cl),
% i.e., recognized as inj; lit significantly interacted with EU.
% Account for this in EU_AssignHH by calling hh.EA.large.stock!

ImpData.numdesc = 9;
varname = char(... %ImpData.(varname[cl]) must exist
    'Elec_Use_marg_cl'...
    ); 
outputname = char(...
    'ln'...
    );
Input = ImpData2Cl_Nx2(Input,ImpData,varname,outputname,'EU','none','none','bycl');     

ImpData.numdesc = 5;

end