function hh = NI_AssignHH(hh,Input,ImpData,assign_modes,ip)
%NI_ASSIGNHH Define norms and information variables
%%%%%%%%%
% Input: hh, Input, ImpData, and assign_modes structures, ip
%%%%%%%%%
% Returns: hh structure


switch ip
    case 1
        % set variables to assign
        
        % NI levels
        hh.NI.Lit{hh.ClNumber,1} = 0;
        hh.NI.Inj = hh.NI.Lit;
        hh.NI.Desc = hh.NI.Lit;     
end


%% Assign norms and information variables
switch assign_modes.NI
    
    case 1      % cluster-specific assignment       
        disp('assign_modes.NI=1 (cluster-specific assignment).');
        
        for cl = 1:hh.ClNumber % type loop
            
            hh.NI.Desc{cl} = NaN(hh.N(cl),1);
            hh.NI.Inj{cl} = NaN(hh.N(cl),1);
            hh.NI.Lit{cl} = NaN(hh.N(cl),1);
            % initialize learning        
            hh.NI.Learning{cl,1} = zeros(hh.N(cl),1);


            for h = 1:hh.N(cl) % household loop

                % Assign desc levels by cl
                for desc = 1:ImpData.numdesc % descriptive norm loop
                    if rand < Input.NI.desc.CondProb(...
                                desc,cl...
                                ) ...
                            && isnan(hh.NI.Desc{cl}(h))
                        hh.NI.Desc{cl}(h) = desc; % 1,2,...,5
                    end
                end
 
                % Assign inj levels by cl
                for inj = 1:ImpData.numinj % injunctive norm loop
                    if rand < Input.NI.inj.CondProb(...
                                inj,cl...
                                ) ...
                            && isnan(hh.NI.Inj{cl}(h))
                        hh.NI.Inj{cl}(h) = inj/2+.5; 
                        % /2+.5 to maintain original values: 1,1.5,...,5
                    end
                end
								
               % Assign lit levels by cl 
                for lit = 1:ImpData.numlit % literacy loop
                    if rand < Input.NI.lit.CondProb(...
                                lit,cl...
                                ) ...
                            && isnan(hh.NI.Lit{cl}(h))
                        hh.NI.Lit{cl}(h) = lit-1;
                        % -1 to maintain original values: 0,1,...,11
                    end
                end
                
            end % close hh loop

        end
        
        
    case 2      % cluster- and category-specific assignment 
        disp('assign_modes.NI=2 (cluster- and category-specific assignment).');

        for cl = 1:hh.ClNumber % cluster loop

            hh.NI.Desc{cl} = NaN(hh.N(cl),1);
            hh.NI.Inj{cl} = NaN(hh.N(cl),1);
            hh.NI.Lit{cl} = NaN(hh.N(cl),1);
            % initialize learning        
            hh.NI.Learning{cl,1} = zeros(hh.N(cl),1);


            for h = 1:hh.N(cl) % household loop

                % Assign desc levels by cl and cat
                for desc = 1:ImpData.numdesc % descriptive norm loop
                    if rand < Input.Cat.NI.desc.CondProb(...
                                desc,hh.cat.cat{cl}(h),cl...
                                ) ...
                            && isnan(hh.NI.Desc{cl}(h))
                        hh.NI.Desc{cl}(h) = desc;
                    end
                end
 
                % Assign inj levels by cl and cat
                for inj = 1:ImpData.numinj % injunctive norm loop
                    if rand < Input.Cat.NI.inj.CondProb(...
                                inj,hh.cat.cat{cl}(h),cl...
                                ) ...
                            && isnan(hh.NI.Inj{cl}(h))
                        hh.NI.Inj{cl}(h) = inj/2+.5;
                    end
                end
								
               % Assign lit levels by cl and cat
                for lit = 1:ImpData.numlit % literacy loop
                    if rand < Input.Cat.NI.lit.CondProb(...
                                lit,hh.cat.cat{cl}(h),cl...
                                ) ...
                            && isnan(hh.NI.Lit{cl}(h))
                        hh.NI.Lit{cl}(h) = lit-1;
                    end
                end

            end % close hh loop

        end 
        
    otherwise
        error('assign_modes.NI=%.0f not defined. \nMust be 1 (cluster-specific) or 2 (cluster-cattegory-specific).',...
            assign_modes.NI);
end

% initialize (or set up) old lit level (required for simulation)
for cl = 1:hh.ClNumber % type loop
    hh.NI.LitOld{cl,1}= zeros(hh.N(cl),1);
end



