function NI_Plot(hh,report,SimName,ip)
%NI_PLOT uses hh and report structures to plot figures on NI
%%%%%%%%%
% Input: hh and report structures, ip counter
%%%%%%%%%
% Returns: Figures, saved in results folder

% get colormap
rgb(1,:)= [0,0,0];
rgb(2,:)= HInt2RGB(1,100); % red, darkest
rgb(3,:)= HInt2RGB(7,82); % cyan, less dark
rgb(4,:)= HInt2RGB(3,64); % green, less dark
rgb(5,:)= HInt2RGB(9,46); % magenta, less dark
rgb(6,:)= HInt2RGB(2,28); % orange, less dark
rgb(7,:)= HInt2RGB(7,10); % blue cyan, lightest

% General plot
figure;

subplot(3,1,1);
plot(report.NI.Desc(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
title('Average strength of descriptive norm');
xlabel('Time')

subplot(3,1,2);
plot(report.NI.Inj(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
title('Average strength of injunctive norm');
xlabel('Time')

subplot(3,1,3);
plot(report.NI.Lit(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
title('Average level of literacy');
xlabel('Time')

name=[SimName,'_NI_aggregate'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');


% Cluster-specific plot
figure;

subplot(3,1,1);
hold on;
plot(report.NI.Desc(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.NI.Desc(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
hold off;
title('Average strength of descriptive norm');
xlabel('Time')

subplot(3,1,2);
hold on;
plot(report.NI.Inj(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.NI.Inj(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
hold off;
title('Average strength of injunctive norm');
xlabel('Time')

subplot(3,1,3);
hold on;
plot(report.NI.Lit(1:ip), 'LineWidth',2, 'Color',rgb(1,:));
for cl=1:hh.ClNumber
    plot(report.Cl.NI.Lit(1:ip,cl), 'LineWidth',1, 'Color',rgb(cl+1,:));
end
leg=legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
% Programatically move the Legend
newPosition = [0.4 0 0.25 0.03]; %[l->r b->t rel_size not_outside]
newUnits = 'normalized';
set(leg,'Position', newPosition,'Units', newUnits);
hold off;
title('Average level of literacy');
xlabel('Time')


name=[SimName,'_NI_by_cluster'];
print([pwd '\results\simulation\' name],'-dpdf','-bestfit');

clearvars name leg newUnits newPosition name 
end