function report = NI_Reporting(hh, report, ip, maxiter)
%NI_REPORTING Reporting of period-specific NI measures on the aggregate, 
% cluster and individual level.
%%%%%%%%%
% Input: hh structure, report structure, ip, and maxiter [opt]
%%%%%%%%%
% Returns: report structure

N=sum(hh.N); 

switch ip
    case 1 % initial period
        disp('NI Reporting for initial setup.')
        % Use initial period to setup reporting structure
        % Aggregate NI reporting measures
        report.NI.Lit = NaN(maxiter+1,1);
        report.NI.Inj = report.NI.Lit;
        report.NI.Desc = report.NI.Lit;
        
        % NI reporting measures by cluster
        report.Cl.NI.Lit = NaN(maxiter+1,hh.ClNumber);
        report.Cl.NI.Inj = report.Cl.NI.Lit;
        report.Cl.NI.Desc = report.Cl.NI.Lit;

        % Individual NI reporting measures
        report.hh.NI.Lit{hh.ClNumber,maxiter+1} = 0;
        for period=1:maxiter+1 % do NOT use same index as for iteration!
            for cluster=1:hh.ClNumber
                report.hh.NI.Lit{cluster,period}=NaN(hh.N(cluster),1);
            end
        end
        report.hh.NI.Inj = report.hh.NI.Lit;
        report.hh.NI.Desc = report.hh.NI.Lit;

end

% NI reporting
% ... aggregate
report.NI.Lit(ip) = sum(cell2mat(hh.NI.Lit))/N;
report.NI.Inj(ip) = sum(cell2mat(hh.NI.Inj))/N;
report.NI.Desc(ip) = sum(cell2mat(hh.NI.Desc))/N;

for cl=1:hh.ClNumber 
    % ... cluster
    report.Cl.NI.Lit(ip,cl)=sum(hh.NI.Lit{cl,1}(:)/hh.N(cl));
    report.Cl.NI.Inj(ip,cl)=sum(hh.NI.Inj{cl,1}(:)/hh.N(cl));
    report.Cl.NI.Desc(ip,cl)=sum(hh.NI.Desc{cl,1}(:)/hh.N(cl));
    
    % ... individuum
    report.hh.NI.Lit{cl,ip} = hh.NI.Lit{cl,1};
    report.hh.NI.Inj{cl,ip} = hh.NI.Inj{cl,1};
    report.hh.NI.Desc{cl,ip} = hh.NI.Desc{cl,1};
end

end