function NW = NW_Plot(NW,NWname)
%NW_Plot Build matrix of connection-weights & create graph of network
%%%%%%%%%
% Input
% NW: NW struct for which to create graph
% NWname (optional): Name to save graph
%%%%%%%%%
% Returns: NW structure, to which it adds
% NW.ConnectionWeights: # of connections between 
%   any two networks of NW
% graph of network, saved in results folder as
%   NWname_NetworkPlot.pdf

if ~exist('NWname','var')
     % NWname does not exist
    getname = @(x) inputname(1);
    NWname = getname(NW);
end
 
if NW.Set.BelongTwo==0
    warning('NW.Set.BelongTwo = 0. No connection between NWs. No plot is being created.')
    return
end

if NW.Number==1
    warning('NW.Number = 1. No network structure. No plot is being created.')
    return
end

%load NW structure as matrix
NWID = cell2mat(NW.ID_cl6);
NWID2 = cell2mat(NW.ID2_cl6);

% kick out all hh belonging to only one NW.
NW2(:,1:2) = NWID(NWID2==1,1:2);

%  make sure the higher NW identifier comes in first column
NWIDswap = (NW2(:,1)<NW2(:,2));
NWIDsort = NW2;
NWIDsort(NWIDswap,1) = NW2(NWIDswap,2);
NWIDsort(NWIDswap,2) = NW2(NWIDswap,1);

weight = zeros(NW.Number);
% fill weight matrix row by row ...
for row=2:numel(NW.Size)
    % ... and colum by column (from 1:diagonale-1)
    for col=1:row-1
        
        IndicateConnections = (NWIDsort(:,1)==row & NWIDsort(:,2)==col);
        
        % create bottom left triangle of weight matrix
        weight(row,col) = sum(IndicateConnections);
        
        % mirror bottom left triangle to top righ of matrix
        weight(col,row) = weight(row,col);
    end
end

% save weight in NW struct
NW.ConnectionWeights = weight;

% plot resulting structure
G = graph(weight);
LWidths = 2*G.Edges.Weight/max(G.Edges.Weight);
h = plot(G,'LineWidth',LWidths);
% normalize NW.Size
NormNWSize=NW.Size./mean(NW.Size);
for i = 1:numel(NW.Size)
    highlight(h,i, 'MarkerSize', NormNWSize(i)*10) 
    % adjust counts to get reasonable markerSize
end
set(gca,'YTick',[]); %get rid of all the markings for the y axis
set(gca,'XTick',[]); %get rid of all the markings for the x axis
axis tight
orient landscape
title(sprintf('Graph for network %s (N = %.0f, SetMeanSize = %.0f, ActMeanSize = %.0f, BelongTwo = %.2f, ClCorr = %.2f)',...
    NWname,numel(NWID(:,1)),NW.Set.MeanSize,NW.ActMeanSize,NW.Set.BelongTwo,NW.Set.ClCorr));
name=sprintf('Network_%s',NWname);
print([pwd '\results\' name],'-dpdf','-bestfit');
print([pwd '\results\' name],'-dpng');

% title(sprintf('Network %s',...
%     NWname));
% name=sprintf('Network_%s',NWname);
% print([pwd '\results\' name],'-dpng');


end