function ReportNW = NW_Reporting(ReportNW,NW,ip,maxiter,modes)
%NW_Reporting Save NW setup and changes in NW characteristics
%%%%%%%%%
% Input
% NW structure
% ip: iteration period to store period-specific info
% maxiter: iteration limit to setup variable sizes
% modes.EA, modes.NI: report EA and NI only if 'active'
%%%%%%%%%
% Returns: ReportNW structure, with Setup field
%   and EA and NI fields (if activated)

switch ip
    case 1 % initial period
        disp('NW Reporting for initial setup.')
        
        % save composition and setup
        ReportNW.Setup=NW; 
        
        ReportNW.NI.Lit = NaN(maxiter+1,NW.Number);
        ReportNW.NI.Inj = ReportNW.NI.Lit;
        ReportNW.NI.Desc = ReportNW.NI.Lit;
        
        switch modes.EA
            case 'active'
                ReportNW.EA.large = NaN(maxiter+1,NW.Number);
                ReportNW.EA.large_EEA = ReportNW.EA.large;
                ReportNW.EA.large_EEA_share = ReportNW.EA.large;
                ReportNW.EA.large_EEA_PreferredShare = ReportNW.EA.large;
                ReportNW.EA.large_EEA_PreferredShareMax = ReportNW.EA.large;
                ReportNW.EA.large_EEA_PreferredStock = ReportNW.EA.large;
                ReportNW.EA.Buy_EEAShare = ReportNW.EA.large;

                
                ReportNW.EA.stock = ReportNW.EA.large;
        end
        
        switch modes.EU
            case 'active'
                ReportNW.EU.level = NaN(maxiter+1,NW.Number);
        end
						
%     otherwise % for ip > 1
%         fprintf('NW Reporting for iteration period ip=%.0f. ',ip)

end

ReportNW.NI.Lit(ip,:) = NW.NI.Lit;
ReportNW.NI.Inj(ip,:) = NW.NI.Inj; 
ReportNW.NI.Desc(ip,:) = NW.NI.Desc;

switch modes.EA
    case 'active'
        ReportNW.EA.large(ip,:) = NW.EA.large.stock;
        ReportNW.EA.large_EEA(ip,:) = NW.EA.large.EEA.stock;
        ReportNW.EA.large_EEA_share(ip,:) = NW.EA.large.EEA.share;
        ReportNW.EA.large_EEA_PreferredShare(ip,:) = NW.EA.large.EEA.PreferredShare; 
        ReportNW.EA.large_EEA_PreferredShareMax(ip,:) = NW.EA.large.EEA.PreferredShareMax; 
        ReportNW.EA.large_EEA_PreferredStock(ip,:) = NW.EA.large.EEA.PreferredStock;
        ReportNW.EA.Buy_EEAShare(ip,:) = NW.EA.Buy.EEAshare;


        ReportNW.EA.stock(ip,:) = ...
             ReportNW.EA.large(ip,:);
end

switch modes.EU
    case 'active'
        ReportNW.EU.level(ip,:) = NW.EU.level;
end

% toc

end