function NW = NW_Update(NW,hh,modes)
%NW_UPDATE Generates/updates EA, EU and NI information
%%%%%%%%%
% Input: NW structure, hh structure, modes structure
%%%%%%%%%
% Returns: NW structure, with EA and NI fields (if activated)
% (Don't know why I need double transpose to get column-vector.)

Desc = cell2mat(hh.NI.Desc); 
Inj = cell2mat(hh.NI.Inj); 
Lit = cell2mat(hh.NI.Lit); 


for n=1:NW.Number
    NW.NI.Desc(n) = ...
        sum(Desc(NW.Members(n,1:NW.Size(n)))) ...
        / NW.Size(n);
    NW.NI.Inj(n) = ...
        sum(Inj(NW.Members(n,1:NW.Size(n)))) ...
        / NW.Size(n);
    NW.NI.Lit(n) = ...
        sum(Lit(NW.Members(n,1:NW.Size(n)))) ...
        / NW.Size(n);
end

switch modes.EA
    case 'active'
        largestock = cell2mat(hh.EA.large.stock); % must be 1xhh.N(cl) arrays
        largeEEAstock = cell2mat(hh.EA.large.EEA.stock); 
        largeEEAshare = cell2mat(hh.EA.large.EEA.share); 
        largeEEAPreferredShare = cell2mat(hh.EA.large.EEA.PreferredShare); 
        largeEEAPreferredStock = cell2mat(hh.EA.large.EEA.PreferredStock); 

        BuyLarge = cell2mat(hh.EA.Buy.large);
        BuyEEA = cell2mat(hh.EA.Buy.EEA);
        
        
        CSincrease = cell2mat(hh.EA.ChangeStock.increase);


        for n=1:NW.Number
            NW.EA.large.stock(n) = ...
                sum(largestock(NW.Members(n,1:NW.Size(n)))) ...
                / NW.Size(n);
            NW.EA.large.EEA.stock(n) = ...
                sum(largeEEAstock(NW.Members(n,1:NW.Size(n)))) ...
                / NW.Size(n);
            NW.EA.large.EEA.share(n) = ...
                sum(largeEEAshare(NW.Members(n,1:NW.Size(n)))) ...
                / NW.Size(n);
            NW.EA.large.EEA.PreferredShare(n) = ...
                sum(largeEEAPreferredShare(NW.Members(n,1:NW.Size(n)))) ...
                / NW.Size(n);
            NW.EA.large.EEA.PreferredShareMax(n) = ...
                max(largeEEAPreferredShare(NW.Members(n,1:NW.Size(n))));
            NW.EA.large.EEA.PreferredStock(n) = ...
                sum(largeEEAPreferredStock(NW.Members(n,1:NW.Size(n)))) ...
                / NW.Size(n);
            
            NW.EA.Buy.large(n) = ...
                sum(BuyLarge(NW.Members(n,1:NW.Size(n)))) / NW.Size(n);
            NW.EA.Buy.EEA(n) = ...
                sum(BuyEEA(NW.Members(n,1:NW.Size(n)))) / NW.Size(n);


            NW.EA.stock(n) = ...
                NW.EA.large.stock(n);

            NW.EA.ChangeStock.increase(n) = ...
                sum(CSincrease(NW.Members(n,1:NW.Size(n)))) ...
                / NW.Size(n);
        end
        
        NW.EA.Buy.EEAshare = NW.EA.Buy.EEA./NW.EA.Buy.large;

end

switch modes.EU
    case 'active'
         eulevel = cell2mat(hh.EU.level);
         effort = cell2mat(hh.EU.Effort);
         effortlevel = cell2mat(hh.EU.EffortLevel);
         
         for n=1:NW.Number
             NW.EU.level(n) = ...
                 sum(eulevel(NW.Members(n,1:NW.Size(n)))) ...
                    / NW.Size(n);
             NW.EU.Effort(n) = ...
                 sum(effort(NW.Members(n,1:NW.Size(n)))) ...
                    / NW.Size(n);
             NW.EU.EffortLevel(n) = ...
                 sum(effortlevel(NW.Members(n,1:NW.Size(n)))) ...
                    / NW.Size(n);   
               
         end
end

end

