function report = Simulation(hh,report,NW,modes,options,maxiter,SimName)
%SIMULATION Simulation loop and reporting (data and graphs)
%%%%%%%%%
% Input: hh, report, NW, modes, active, maxiter, SimName 
%%%%%%%%%
% Returns/updates: report structure


%% Setup
if ~exist('SimName','var')
    % SimName does not exist
    SimName = ['Sim_',strrep(datestr(datetime('now')),' ','_')];
    SimName = strrep(SimName,':','-');
    warning('SimName was not assigned. Set to %s.',SimName)
end

fprintf('\n\nRunning simulation %s\nID: Number of activated channels = %.0f\nEA: ChangeStock = %.0f, RandomBuy = %.0f, TechnicalPS = %.0f, YearsIntroLabel = %.0f. \nEU: EEAEnergyReduction = %.2f, EUDesc = %.0f. \nNW: NWon = %.0f, WeightPSMax = %.2f.\n'...
    ,SimName,...
    numel(options.ID.PickMates(:,1)),...
    options.EA.ChangeStock,options.EA.RandomBuy,options.EA.TechnicalPS,...
    options.EA.YearsIntroLabel,options.EU.EEAEnergyReduction,options.EU.Desc,...
    options.NW.NWon,options.NW.WeightPSMax)

report.setup.options = options; % save specification of SimName

%% Interval loop
for ip= 2:maxiter+1 % +1 to account for initial round 1  
    fprintf('Iteration period ip = %.0f. ',ip)
    
    % Information diffusion
     switch modes.ID
        case 'active'   
            ID = struct;
            % Institutional ID
            [hh,ID] = ID_Institutions(hh,NW,ID,report,modes,options,ip);
            report = ID_InstReport(hh,ID,options,report,ip,maxiter);
                     
            % Conversations
            for id = 1:numel(options.ID.PickMates(:,1))
                PM = strrep(options.ID.PickMates(id,:),' ','');
                [hh,ID.(PM)] = ID_Conversations(hh,NW,modes,options,PM);
                report = ID_ConvReport(PM,hh,ID,options,report,ip);
            end
            
        case 'inactive' % do nothing
        otherwise
            fprintf('modes.ID = %s not specified. Must be active or inactive. Set to inactive.\n'...
                ,modes.ID);
            modes.ID = 'inactive';
    end
    
    % Adjustment of preferred share and effort
    switch modes.BehavioristicAdjustment
        case 'active'    
            hh = BehavioristicAdjustment(hh,NW,modes,options,ip);
            [report,hh] = BehavioristicAdjustment_Reporting(hh, report, ip); 
    end
    
    % EA decisions and reporting
    switch modes.EA
        case 'active'
            hh = EA_DecisionMaking(hh,NW,modes,options,ip);
            report = EA_Reporting(hh, report, ip); 
    end 
    
    % Electricity Usage 
    switch modes.EU
        case 'active'
            hh = EU_DecisionMaking(hh,NW,report.Cl.EU.level(ip-1,:),options);
            report = EU_Reporting(hh, report, ip);
    end
    
    
    % Information and trust report (and, potentially, update; still tbd)
    switch modes.IT
        case 'active'
            report = IT_Reporting(hh,report,ip,maxiter);
    end
    
    % Network updates
    for nw = 1:numel(options.NW.NWNames(:,1))
        NWName = (strrep(options.NW.NWNames(nw,:),' ','')); % set fieldname
        NW.(NWName) = NW_Update(NW.(NWName),hh,modes);
        report.NW.(NWName) = NW_Reporting(report.NW.(NWName),...
            NW.(NWName),ip,maxiter,modes);
    end
    
    toc
    
end % close interval loop


%% Visualization of results
switch options.plots_active
    case 1
        switch modes.ID
            case 'active'
                for id = 1:numel(options.ID.PickMates(:,1))
                    PM = strrep(options.ID.PickMates(id,:),' ','');
                    ID_Plot(PM,hh,report,SimName,ip)
                end
                for j = 1:numel(options.ID.Inst.Channels(:,1))
                    AC = strrep(options.ID.Inst.Channels(j,:),' ','');
                    ID_InstPlot(AC,hh,report,SimName,ip)
                end

        end

        switch modes.EA
            case 'active'
                EA_Plot(hh,report,SimName,ip)
        end

        switch modes.EU
            case 'active'
                EU_Plot(hh,report,SimName,ip)
        end
end
   
end