function [predict,se] = importNx2(filename, startRow, endRow)
%IMPORTFILE1 Import numeric data from a text file as column vectors.
%   [PREDICT,SE] = importNx2(FILENAME) Reads data from text file
%   FILENAME for the default selection.
%
%   [PREDICT,SE] = importNx2(FILENAME, STARTROW, ENDROW) Reads
%   data from rows STARTROW through ENDROW of text file FILENAME.
%
% Example:
%   [predict,se] = importfile1('EEA_marg_cl.csv',2, 301);
%
%    See also TEXTSCAN.

% Auto-generated by MATLAB on 2018/08/08 17:25:17

%% Initialize variables.
if nargin<=2
    startRow = 2;
    endRow = inf;
end

try
    delimiter = '\t';
    % Format for each line of text:
    %   column2: double (%f)
    %	column3: double (%f)
    % For more information, see the TEXTSCAN documentation.
    formatSpec = '%*s%f%f%[^\n\r]';

    % Open the text file.
    fileID = fopen(filename,'r');

    % Read columns of data according to the format.
    % This call is based on the structure of the file used to generate this
    % code. If an error occurs for a different file, try regenerating the code
    % from the Import Tool.
    dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');

    if sum(isnan(dataArray{1,1}))>0
        error('delimiter of %s not %s, try comma as delimiter.',filename,delimiter)
    end
    
catch
    warning('delimiter of %s not %s, try comma as delimiter.',filename,delimiter)
    
    delimiter = ',';
    % Format for each line of text:
    %   column2: double (%f)
    %	column3: double (%f)
    % For more information, see the TEXTSCAN documentation.
    formatSpec = '%*s%f%f%[^\n\r]';

    % Open the text file.
    fileID = fopen(filename,'r');

    % Read columns of data according to the format.
    % This call is based on the structure of the file used to generate this
    % code. If an error occurs for a different file, try regenerating the code
    % from the Import Tool.
    dataArray = textscan(fileID, formatSpec, endRow(1)-startRow(1)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(1)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');

    if sum(isnan(dataArray{1,1}))>0
        error('delimiter of %s neither \t nor %s. Check input format of %s.',filename,delimiter,filename)
    end
    
end

for block=2:length(startRow)
    frewind(fileID);
    dataArrayBlock = textscan(fileID, formatSpec, endRow(block)-startRow(block)+1, 'Delimiter', delimiter, 'HeaderLines', startRow(block)-1, 'ReturnOnError', false, 'EndOfLine', '\r\n');
    for col=1:length(dataArray)
        dataArray{col} = [dataArray{col};dataArrayBlock{col}];
    end
end

%% Close the text file.
fclose(fileID);

%% Post processing for unimportable data.
% No unimportable data rules were applied during the import, so no post
% processing code is included. To generate code which works for
% unimportable data, select unimportable cells in a file and regenerate the
% script.

%% Allocate imported array to column variable names
predict = dataArray{:, 1};
se = dataArray{:, 2};


