function SimReport_sr = reporting_sr(SimReport,maxsr,sr_names,maxiter,SimName)
%%% reporting of all simulation repetitions

%% report avg and std over all repetitions
for sr = 1:maxsr
    for ip= 1:maxiter+1
        SimReport_sr.(SimName).EU(ip,sr) = SimReport.(SimName).(sr_names{sr,1}).EU.level(ip,:);
        SimReport_sr.(SimName).EEAshare(ip,sr) = SimReport.(SimName).(sr_names{sr,1}).EA.large_EEA_share(ip,:);
        for cl = 1:5
            SimReport_sr.(SimName).EU_Cl(ip,cl,sr) = SimReport.(SimName).(sr_names{sr,1}).Cl.EU.level(ip,cl);
            SimReport_sr.(SimName).EEAshare_Cl(ip,cl,sr) = SimReport.(SimName).(sr_names{sr,1}).Cl.EA.large_EEA_share(ip,cl);
        end
    end
end

for ip = 1:maxiter+1
    SimReport_sr.(SimName).EU_avg(ip,1) = mean(SimReport_sr.(SimName).EU(ip,:));
    SimReport_sr.(SimName).EU_std(ip,1) = std(SimReport_sr.(SimName).EU(ip,:));
    
    SimReport_sr.(SimName).EEAshare_avg(ip,1) = mean(SimReport_sr.(SimName).EEAshare(ip,:));
    SimReport_sr.(SimName).EEAshare_std(ip,1) = std(SimReport_sr.(SimName).EEAshare(ip,:));
    
    for cl = 1:5
        SimReport_sr.(SimName).EU_Cl_avg(ip,cl) = mean(SimReport_sr.(SimName).EU_Cl(ip,cl,:));
        SimReport_sr.(SimName).EU_Cl_std(ip,cl) = std(SimReport_sr.(SimName).EU_Cl(ip,cl,:));
        SimReport_sr.(SimName).EEAshare_Cl_avg(ip,cl) = mean(SimReport_sr.(SimName).EEAshare_Cl(ip,cl,sr));
        SimReport_sr.(SimName).EEAshare_Cl_std(ip,cl) = std(SimReport_sr.(SimName).EEAshare_Cl(ip,cl,sr));
    end
end

%% plots
rgb(1,:)= [0,0,0];
iter = 1:1:maxiter+1;

% eu level
figure;
hold on
errorbar(iter,SimReport_sr.(SimName).EU_avg(1:maxiter+1,1),SimReport_sr.(SimName).EU_std(1:maxiter+1,1),...
    'LineWidth',1,'Color',rgb(1,:),'LineStyle',':');
for cl=1:5
    errorbar(iter,SimReport_sr.(SimName).EU_Cl_avg(1:maxiter+1,cl),SimReport_sr.(SimName).EU_Cl_std(1:maxiter+1,cl));
end
ylabel('EU Level [KWh/year]')
xlabel('Years')
xticks(1:1:maxiter+1)
legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
hold off
filename=[(SimName) '_EU'];
print([pwd '\results\simulation\' filename],'-dpng');

% eea share
figure;
hold on
errorbar(iter,SimReport_sr.(SimName).EEAshare_avg(1:maxiter+1,1),SimReport_sr.(SimName).EEAshare_std(1:maxiter+1,1),...
    'LineWidth',1,'Color',rgb(1,:),'LineStyle',':');
for cl=1:5
    errorbar(iter,SimReport_sr.(SimName).EEAshare_Cl_avg(1:maxiter+1,cl),SimReport_sr.(SimName).EEAshare_Cl_std(1:maxiter+1,cl));
end
ylabel('EEA Share')
xlabel('Years')
xticks(1:1:maxiter+1)
legend({'avg','Cl1','Cl2','Cl3','Cl4','Cl5'}...
    ,'Location','southoutside'...
    ,'Orientation','horizontal'...
    ,'FontSize',7 ...
    );
hold off
filename=[(SimName) '_EEAshare'];
print([pwd '\results\simulation\' filename],'-dpng');

close all

end % end of function